// Created by Microsoft (R) C/C++ Compiler Version 14.50.35722.0 (b436dbf8).
//
// C++ source equivalent of type library zt.tlb
// compiler-generated file - DO NOT EDIT!

#pragma once
#pragma pack(push, 8)

#include <comdef.h>

//
// Forward references and typedefs
//

struct __declspec(uuid("9fbbc98e-ae78-4a1c-b635-1eca2fbffb40"))
/* LIBID */ __AiSquared;
enum AiSquaredLibraryVersion : int;
struct __declspec(uuid("cc675e9b-d54b-4752-aebe-20f1b6496201"))
/* dual interface */ IZTCommand;
struct __declspec(uuid("de188a1c-7426-46f4-95e2-4004a5f664d9"))
/* dual interface */ IZoomText;
struct __declspec(uuid("ba722d2b-4323-495d-84ff-39d694d170bb"))
/* dual interface */ IAhoiManager2;
struct __declspec(uuid("ccb88338-5d06-4d72-8e08-526eabed4458"))
/* dual interface */ IAhoiManager;
struct __declspec(uuid("e0140240-fba2-4e2b-a4ed-e7ad176e7bc6"))
/* dual interface */ IEventManager2;
struct __declspec(uuid("5d2381cf-0b7d-4554-b3a6-e67f6e98dfb3"))
/* dual interface */ IEventManager;
struct __declspec(uuid("83012579-fec8-4b8a-a6b6-9e9144a7e47f"))
/* dual interface */ IEventDefinition;
struct __declspec(uuid("8e5f9c98-48c4-4322-ab3f-d08879d91555"))
/* dual interface */ IHotkeys2;
struct __declspec(uuid("f8d5580b-bb40-4fbc-a88d-d4ee782bee0e"))
/* dual interface */ IHotkeys;
struct __declspec(uuid("04972fbc-5254-11dc-8314-0800200c9a66"))
/* dual interface */ IKeyboard;
struct __declspec(uuid("7fecb1f1-c6d4-4f80-87b4-06dcaabebf57"))
/* dual interface */ IMagnification3;
struct __declspec(uuid("b8ee8cbb-6357-44ef-a024-0b756d0d7730"))
/* dual interface */ IMagnification2;
struct __declspec(uuid("33fbe571-a41d-49cf-84c7-5e2207e37e98"))
/* dual interface */ IMagnification;
struct __declspec(uuid("a05e200e-7e70-4c7e-99ac-795bba608809"))
/* dual interface */ ICaretEnhancements4;
struct __declspec(uuid("bb0a2d5b-960f-4c98-beed-4454b73a36f1"))
/* dual interface */ ICaretEnhancements3;
struct __declspec(uuid("92efd367-80cc-4ddc-a841-ea000c531d39"))
/* dual interface */ ICaretEnhancements2;
struct __declspec(uuid("d0433f69-0d8c-4775-83f9-1f04f97c3a72"))
/* dual interface */ ICaretEnhancements;
struct __declspec(uuid("22ab4f67-91c3-4dd9-9bc0-5bd1d5ab9b90"))
/* dual interface */ IRectangle;
struct __declspec(uuid("9453cdaf-1e08-4861-a5ab-599dd5e7fd09"))
/* dual interface */ IColorEnhancements2;
struct __declspec(uuid("0370fad7-0e6b-46f1-a008-c6d689493fce"))
/* dual interface */ IColorEnhancements;
struct __declspec(uuid("71c6bc10-ca7b-4812-8b1f-b64cb7a509e7"))
/* dual interface */ IDualMonitor;
struct __declspec(uuid("d90db93e-eef3-461b-9cd6-199bb252ef3b"))
/* dual interface */ IFocusEnhancements4;
struct __declspec(uuid("9859118a-4c6f-41e8-a28d-a6e6c4480933"))
/* dual interface */ IFocusEnhancements3;
struct __declspec(uuid("58041971-3a0b-4821-a436-6b9471fdfdc4"))
/* dual interface */ IFocusEnhancements2;
struct __declspec(uuid("2e51ed2f-589a-4c74-b955-273ff8a04177"))
/* dual interface */ IFocusEnhancements;
struct __declspec(uuid("0ee21611-d296-4c6d-8d28-87d7bfc626fa"))
/* dual interface */ IFontEnhancements;
struct __declspec(uuid("b9966bd6-5a59-4a20-b4d5-c97e70807527"))
/* dual interface */ IZoomWindow;
struct __declspec(uuid("ffba1585-96aa-4be7-bf8e-7996be405683"))
/* dual interface */ IPower;
struct __declspec(uuid("4dad7131-ee64-4c3d-82a6-db3763fbb60f"))
/* dual interface */ IPointerEnhancements3;
struct __declspec(uuid("df2b31ee-a0a2-4f5d-8f29-969b91baf248"))
/* dual interface */ IPointerEnhancements2;
struct __declspec(uuid("41c19ac7-4d28-4d3b-a17f-704d0f1b3872"))
/* dual interface */ IPointerEnhancements;
struct __declspec(uuid("0e890643-4d5b-4e20-8a72-80c8ad2511f9"))
/* dual interface */ ITracking2;
struct __declspec(uuid("9a59b310-74f6-4d43-b0ab-1f44da8268e0"))
/* dual interface */ ITracking;
struct __declspec(uuid("91b8c0cd-93cf-46f3-abba-04c61a13ba0c"))
/* dual interface */ IViewLocator;
struct __declspec(uuid("eb53ca25-96d6-4978-bc65-4c3b2118cee5"))
/* dual interface */ IScreenHighlight2;
struct __declspec(uuid("1a1f44c1-83b2-4d12-b6fe-629751c134ec"))
/* dual interface */ IScreenHighlight;
struct __declspec(uuid("050e0e11-3d0a-4f6e-a634-c2270e30dc1b"))
/* dual interface */ ICCTV;
struct __declspec(uuid("4c2662b3-4cf7-4b05-b0b0-53ae74ee8d5d"))
/* dual interface */ IMouse;
struct __declspec(uuid("e9bed2bf-8834-49f9-ad4c-12c3cf7373ad"))
/* dual interface */ IPoint;
struct __declspec(uuid("0c32cc2f-22f4-4980-a4d8-6cda1f1b4d8d"))
/* dual interface */ IReader4;
struct __declspec(uuid("129e7a0e-9e23-469d-a2ca-de3baecaf45d"))
/* dual interface */ IReader3;
struct __declspec(uuid("5f41aadc-84dc-445d-bb22-0fde09b95e91"))
/* dual interface */ IReader2;
struct __declspec(uuid("cde9e8a8-03a7-4413-86a3-aca30f305ac1"))
/* dual interface */ IReader;
struct __declspec(uuid("c4c5a470-4f53-4bbf-a534-ba88e9fbbe5f"))
/* dual interface */ IAppReader;
struct __declspec(uuid("0472df6c-835a-4180-a35a-a5608fa2fce8"))
/* dual interface */ IMouseEcho2;
struct __declspec(uuid("1203b332-4ef0-41fd-bc24-763503b8dc90"))
/* dual interface */ IMouseEcho;
struct __declspec(uuid("a0a71491-2b73-43f3-9e6b-5a9fddddc3d1"))
/* dual interface */ IReadingZones;
struct __declspec(uuid("cb508dd4-5076-4b3c-b792-629d6c37af41"))
/* dual interface */ IReadingZoneObject;
struct __declspec(uuid("865c25b5-9a75-4e41-b182-dca1768255e3"))
/* dual interface */ ITypingEcho;
struct __declspec(uuid("7f5432aa-9729-4fd3-a783-2c02fabe5b86"))
/* dual interface */ IVerbosity;
struct __declspec(uuid("bfff5140-ba03-40b0-8131-ec64673bc735"))
/* dual interface */ IProgramEcho;
struct __declspec(uuid("8423fbeb-feaf-4248-9638-156a7543ea91"))
/* dual interface */ IDocReader;
struct __declspec(uuid("2aeb500e-85ad-4808-836b-2f1512697966"))
/* dual interface */ IRecorder;
struct __declspec(uuid("627f824e-cf7c-43d9-a4cf-1c139a934a2e"))
/* dual interface */ IScriptConfiguration2;
struct __declspec(uuid("ff065601-dc5c-49ad-ab8d-58325885be0b"))
/* dual interface */ IScriptConfiguration;
struct __declspec(uuid("fa636707-c09a-4fd9-8a1b-838a5a505a4c"))
/* dual interface */ IScriptInformation;
struct __declspec(uuid("e73eaf69-0892-48f5-a078-53d37a3b6555"))
/* dual interface */ IZoomTextSettings6;
struct __declspec(uuid("c8050fe3-1249-4b16-a8c9-81dd21b10ad5"))
/* dual interface */ IZoomTextSettings5;
struct __declspec(uuid("84c39c47-0cfb-43a8-b88e-0c6662000877"))
/* dual interface */ IZoomTextSettings4;
struct __declspec(uuid("51b35190-807c-4ac8-b74f-3a3fd83e6f86"))
/* dual interface */ IZoomTextSettings3;
struct __declspec(uuid("e874a180-d7c9-4b21-a638-982d36f5ea7e"))
/* dual interface */ IZoomTextSettings2;
struct __declspec(uuid("ee7b5cc9-bf3e-493d-aed4-a0a0a10a9a8c"))
/* dual interface */ IZoomTextSettings;
struct __declspec(uuid("cd16491d-29de-4cb2-a4d9-2ad423fe3c6e"))
/* dual interface */ ISpeech2;
struct __declspec(uuid("b7271c8c-3a94-4831-883b-81ba18b87664"))
/* dual interface */ ISpeech;
struct __declspec(uuid("a2fbf963-0748-4266-a04b-8c54466126d5"))
/* dual interface */ IVoice;
struct __declspec(uuid("e9ef732f-25ef-4d19-a0d2-fe8f6d3a1bbb"))
/* dual interface */ IObjectCollection;
struct __declspec(uuid("c7149863-61d3-422f-aa2c-0dca654914d5"))
/* dual interface */ ISpeaker;
struct tagAHOIOBJECTID;
struct __declspec(uuid("729772a3-83e7-4d86-a30c-780c24d0bb6c"))
/* dual interface */ IScriptManager;
struct __declspec(uuid("0d7614b7-c695-4527-9b99-aca804aacb5e"))
/* dual interface */ ITextSearch;
struct __declspec(uuid("6820972a-1abd-4bcf-924a-60053fac4a8d"))
/* dual interface */ ITextSearchOption;
struct __declspec(uuid("7dc44c70-d1e4-4477-9e4a-ccdb38c862f7"))
/* dual interface */ ITextObject;
struct __declspec(uuid("30ef42de-166e-4bd4-b864-0bec8dc143f3"))
/* dual interface */ IApplicationObject;
struct __declspec(uuid("a3b6c1b2-5b5a-48d3-889b-f77b4087e860"))
/* dual interface */ IFontObject;
struct __declspec(uuid("a04731f3-3f79-4afd-8658-1673d5e56ece"))
/* dual interface */ ITextCursor;
struct __declspec(uuid("a4e4b0f5-5321-4e2c-9526-a5b33e890d17"))
/* dual interface */ IApplicationSearch;
struct __declspec(uuid("67c6cf6a-afda-44be-bcf9-c70e28c9ee91"))
/* dual interface */ IWindowSearch;
struct __declspec(uuid("5a1f732f-6c70-4b4e-bdf8-b0ecf9500134"))
/* dual interface */ IWindowObject;
struct __declspec(uuid("477f6a4d-ad3d-49be-a990-c56dd52614fb"))
/* dual interface */ ICheckBox;
struct __declspec(uuid("c644815f-2157-4854-861d-e433da8da5b0"))
/* dual interface */ IComboBox;
struct __declspec(uuid("ae0e849f-ed2b-494d-9a02-9db2f021dda5"))
/* dual interface */ IItemObject;
struct __declspec(uuid("37e5004f-2bbd-4800-bd87-b8883b6a2a83"))
/* dual interface */ IEditBox;
struct __declspec(uuid("fb9e3e9b-374d-4e3f-9203-7c3d8f848f41"))
/* dual interface */ ILink;
struct __declspec(uuid("32a532d8-5f54-4e5a-876a-737a87c8cee1"))
/* dual interface */ IListView;
struct __declspec(uuid("836a99ad-bcbe-4534-a8a2-73addfcc7571"))
/* dual interface */ IMenuItem;
struct __declspec(uuid("0680f1b0-823e-4953-a9ff-f52c407a59fd"))
/* dual interface */ IRadioButton;
struct __declspec(uuid("3656a1fc-dfea-4acf-9c78-675be5ea272d"))
/* dual interface */ IScrollBar;
struct __declspec(uuid("68dd54e0-183d-41ae-bf86-4da434814302"))
/* dual interface */ ITrackBar;
struct __declspec(uuid("4f521c31-ee39-4cf7-a200-e9850a9c070c"))
/* dual interface */ ITreeView;
struct __declspec(uuid("8511473e-8fde-4327-bfad-ec59f77fcb3f"))
/* dual interface */ ISpeechEventObject;
struct __declspec(uuid("c27bb1e7-6142-4a9d-8db1-8571b09e4363"))
/* dual interface */ IEnvironment;
struct __declspec(uuid("f71a5b7c-bb03-45ac-9703-ddfff9a94807"))
/* dual interface */ IWindowObject2;
struct __declspec(uuid("d226d606-a89c-4277-a396-ab57f9d2c1bd"))
/* dual interface */ IWindowObjectOption;
struct __declspec(uuid("19e19ae5-d44b-4c67-ba8e-37bdf971bf90"))
/* dual interface */ IHeaderControl;
struct __declspec(uuid("4a9140b5-7c86-4a9c-8ea9-5c84755841e1"))
/* dual interface */ ICheckBox2;
struct __declspec(uuid("a1ca3f99-86f1-4b78-9267-046ad32782c7"))
/* dual interface */ IComboBox2;
struct __declspec(uuid("97787e6b-a70d-4a65-a74a-10a33c031b61"))
/* dual interface */ IItemObject2;
struct __declspec(uuid("ef4fe0d9-8e73-4e99-9d98-4438a4c023b1"))
/* dual interface */ IEditBox2;
struct __declspec(uuid("f2a6d33c-f60b-4e89-98f2-c00b4413befe"))
/* dual interface */ ILink2;
struct __declspec(uuid("ba4119f3-7735-4c7f-980d-f92f20b103d3"))
/* dual interface */ IListView2;
struct __declspec(uuid("e11c2304-a3b0-4f17-8c36-1970d709156a"))
/* dual interface */ IMenuItem2;
struct __declspec(uuid("e81982ec-7a3a-4d15-b126-75ccc520bd81"))
/* dual interface */ IObjectStore;
struct __declspec(uuid("93cefb5d-e673-434a-af70-93d4a6fee9d8"))
/* dual interface */ IRadioButton2;
struct __declspec(uuid("179608af-19d4-4d94-83fc-315814b0c0a9"))
/* dual interface */ IScrollBar2;
struct __declspec(uuid("2f6b91fe-8dad-40c6-8151-d3533585badd"))
/* dual interface */ ITrackBar2;
struct __declspec(uuid("c8d6adcf-e992-45ef-bb3f-a9572dc85752"))
/* dual interface */ ITreeView2;
struct __declspec(uuid("ffc01288-cb56-4c56-b082-eeddd8c0e144"))
/* dual interface */ IWindowSearch2;
struct __declspec(uuid("6f4c7c49-96a6-4c87-926a-79083a19d534"))
/* dual interface */ IWindowSearchOption;
struct __declspec(uuid("87908e23-dcfb-4a32-82c6-5e54c4870d4d"))
/* dual interface */ IWebPage;
struct __declspec(uuid("c954470b-98e8-4214-a011-b556dbdf26a6"))
/* dual interface */ IZoomText2;
struct __declspec(uuid("22e2cc6c-e8e3-4209-bbfd-d4cc65fa613a"))
/* dual interface */ ICCTV2;
struct __declspec(uuid("ac9927f4-c123-4730-b91c-266aaa93d22a"))
/* dual interface */ IMagnification4;
struct __declspec(uuid("4461cd62-37bc-409e-96cd-7f66eab86cfc"))
/* dual interface */ ICCTV3;
struct __declspec(uuid("ab6dcbfd-6aa8-4f70-b3a6-19e9770019b9"))
/* dual interface */ IZoomText3;
struct __declspec(uuid("1cfc89ff-5c33-4db7-aaaf-4b4bf7665d2a"))
/* dual interface */ IMagnification5;
struct __declspec(uuid("46b53ce7-45b6-4ef9-98fd-58de15bd2b33"))
/* dual interface */ ICCTV4;
struct __declspec(uuid("c65cd7e2-45a5-46f4-9165-80c90bdd9e0b"))
/* dual interface */ IZoomText4;
struct __declspec(uuid("79acb813-a53b-4c99-a57f-129b546eb2c3"))
/* dual interface */ IMagnification6;
struct __declspec(uuid("e2edafe4-9f12-4902-9086-5f600516c5da"))
/* dual interface */ IZoomText5;
struct __declspec(uuid("69c6dc1f-d8a0-434d-82ea-f8e48a6da817"))
/* dual interface */ IMagnification7;
struct __declspec(uuid("a595d144-d88d-4724-8a3a-5c937f9f4f29"))
/* dual interface */ ICCTV5;
struct __declspec(uuid("4d2bc8ae-fe6d-41c5-80a1-922f5eb44f59"))
/* dual interface */ IZoomText6;
struct __declspec(uuid("2802ebf9-069f-4245-8e35-77ba2c58f462"))
/* dual interface */ IControl;
struct __declspec(uuid("93eb8471-756d-46fc-9891-ba8d893a1c0d"))
/* dual interface */ IControlApp;
struct __declspec(uuid("a9224504-4499-45ff-a8c9-a327b328fdd5"))
/* dual interface */ IControlAppProperties;
struct __declspec(uuid("1cd1670d-bdd5-4c8f-a918-00e3d540e1bd"))
/* dual interface */ IZoomText7;
struct __declspec(uuid("3e3aee84-0ed6-44a9-a481-fc7770026f02"))
/* dual interface */ IMagnification8;
struct __declspec(uuid("92231697-6ead-408d-9395-6a688b885586"))
/* dual interface */ ISpeaker2;
struct __declspec(uuid("d38f0d27-fc81-4836-8886-0ec9bdb417d3"))
/* dual interface */ IVoice2;
struct __declspec(uuid("b0b9cb1d-3369-482d-8c2e-3cb254dbff0c"))
/* dual interface */ ISpeech3;
struct __declspec(uuid("796718e4-f2b9-4d7d-8970-ac1a26d816f7"))
/* dual interface */ IZoomText8;
struct __declspec(uuid("97ea7ed1-3acc-4cba-8df9-4ecbe9558271"))
/* dual interface */ IFontEnhancements2;
struct __declspec(uuid("d1d89c6e-4cdb-4b66-af63-57ca40555407"))
/* dual interface */ IMagnification9;
struct __declspec(uuid("d629bc1e-21e2-4509-9347-e7d3fadf8470"))
/* dual interface */ IZoomText9;
struct __declspec(uuid("9a67b4ec-2046-4227-80ca-44739b3b5256"))
/* dual interface */ ITetheredViewSettings;
struct __declspec(uuid("915c2a11-8a83-4608-9aef-aa9afb47b8e0"))
/* dual interface */ ITetheredViewScenario;
struct __declspec(uuid("9b031763-5952-453e-8688-dca3c5c656b3"))
/* dual interface */ IZoomText10;
struct __declspec(uuid("09ef40d5-8ea2-48d7-a760-3317e3cab2dc"))
/* dual interface */ IMagnification10;
struct /* coclass */ ZoomText;
struct __declspec(uuid("d4c0c54a-5414-42e7-b153-62c9b3e7febf"))
/* dual interface */ IZoomText11;
struct __declspec(uuid("ff32c95f-83aa-4bbb-bde9-ecd790ef85fb"))
/* dual interface */ IMagnification11;

//
// Type library items
//

enum AiSquaredLibraryVersion : int
{
    TypeLibMajorVersion = 1,
    TypeLibMinorVersion = 2
};

struct __declspec(uuid("cc675e9b-d54b-4752-aebe-20f1b6496201"))
IZTCommand : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall Command (
        /*[in]*/ int iCommand,
        /*[in]*/ long lParam ) = 0;
      virtual HRESULT __stdcall CommandString (
        /*[in]*/ int iCommand,
        /*[in]*/ BSTR strParam ) = 0;
};

struct __declspec(uuid("ccb88338-5d06-4d72-8e08-526eabed4458"))
IAhoiManager : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Enabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_Enabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
      virtual HRESULT __stdcall EnableModule (
        /*[in]*/ BSTR bstrAhoiModuleName ) = 0;
      virtual HRESULT __stdcall DisableModule (
        /*[in]*/ BSTR bstrAhoiModuleName ) = 0;
      virtual HRESULT __stdcall IsModuleEnabled (
        /*[in]*/ BSTR bstrAhoiModuleName,
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall IsModuleRegistered (
        /*[in]*/ BSTR bstrAhoiModuleName,
        /*[out,retval]*/ VARIANT_BOOL * pbRegistered ) = 0;
};

struct __declspec(uuid("ba722d2b-4323-495d-84ff-39d694d170bb"))
IAhoiManager2 : IAhoiManager
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_FocusEventsEnabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_FocusEventsEnabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
      virtual HRESULT __stdcall get_CursorEventsEnabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_CursorEventsEnabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
};

struct __declspec(uuid("83012579-fec8-4b8a-a6b6-9e9144a7e47f"))
IEventDefinition : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Event (
        /*[out,retval]*/ BSTR * pbstrEvent ) = 0;
      virtual HRESULT __stdcall put_Event (
        /*[in]*/ BSTR pbstrEvent ) = 0;
      virtual HRESULT __stdcall get_ScriptPath (
        /*[out,retval]*/ BSTR * pbstrScriptPath ) = 0;
      virtual HRESULT __stdcall put_ScriptPath (
        /*[in]*/ BSTR pbstrScriptPath ) = 0;
      virtual HRESULT __stdcall get_ProgramID (
        /*[out,retval]*/ BSTR * pbstrProgramID ) = 0;
      virtual HRESULT __stdcall put_ProgramID (
        /*[in]*/ BSTR pbstrProgramID ) = 0;
      virtual HRESULT __stdcall get_AlternateMethod (
        /*[out,retval]*/ BSTR * pbstrMethod ) = 0;
      virtual HRESULT __stdcall put_AlternateMethod (
        /*[in]*/ BSTR pbstrMethod ) = 0;
      virtual HRESULT __stdcall get_CancelEventOnAlert (
        /*[out,retval]*/ VARIANT_BOOL * pbCancel ) = 0;
      virtual HRESULT __stdcall put_CancelEventOnAlert (
        /*[in]*/ VARIANT_BOOL pbCancel ) = 0;
      virtual HRESULT __stdcall AddFilterItem (
        /*[in]*/ BSTR bstrName,
        /*[in]*/ VARIANT value,
        /*[in]*/ VARIANT comparisonType = vtMissing ) = 0;
};

struct __declspec(uuid("5d2381cf-0b7d-4554-b3a6-e67f6e98dfb3"))
IEventManager : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall RegisterForEvent (
        /*[in]*/ struct IEventDefinition * pEventDef ) = 0;
      virtual HRESULT __stdcall UnregisterFromEvent (
        /*[in]*/ struct IEventDefinition * pEventDef ) = 0;
};

struct __declspec(uuid("e0140240-fba2-4e2b-a4ed-e7ad176e7bc6"))
IEventManager2 : IEventManager
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall CancelEvent (
        /*[in]*/ struct IEventDefinition * pEventDef ) = 0;
};

struct __declspec(uuid("f8d5580b-bb40-4fbc-a88d-d4ee782bee0e"))
IHotkeys : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall CreateHotkey (
        /*[in]*/ BSTR bstrCommandName,
        /*[in]*/ BSTR bstrDescription,
        /*[in]*/ BSTR bstrDefaultKeyCombination ) = 0;
      virtual HRESULT __stdcall DeleteHotkey (
        /*[in]*/ BSTR bstrCommandName ) = 0;
      virtual HRESULT __stdcall Execute (
        /*[in]*/ BSTR bstrCommandName,
        /*[in]*/ VARIANT bSilent = vtMissing ) = 0;
};

struct __declspec(uuid("8e5f9c98-48c4-4322-ab3f-d08879d91555"))
IHotkeys2 : IHotkeys
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall GetLocalizedHotkeyName (
        /*[in]*/ int commandId,
        /*[out,retval]*/ BSTR * bstrName ) = 0;
};

struct __declspec(uuid("04972fbc-5254-11dc-8314-0800200c9a66"))
IKeyboard : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_KeysPressed (
        /*[out,retval]*/ BSTR * bstr ) = 0;
      virtual HRESULT __stdcall PressKeys (
        /*[in]*/ BSTR bstr ) = 0;
      virtual HRESULT __stdcall GetKeyCode (
        /*[in]*/ BSTR bstr,
        /*[out,retval]*/ unsigned long * pdwKeyCode ) = 0;
      virtual HRESULT __stdcall GetKeyName (
        /*[in]*/ unsigned short wModifier,
        /*[in]*/ unsigned short wVkCode,
        /*[in]*/ unsigned short wUC,
        /*[out,retval]*/ BSTR * keyString ) = 0;
};

struct __declspec(uuid("d0433f69-0d8c-4775-83f9-1f04f97c3a72"))
ICaretEnhancements : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Enabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_Enabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
};

struct __declspec(uuid("22ab4f67-91c3-4dd9-9bc0-5bd1d5ab9b90"))
IRectangle : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall Empty (
        /*[out,retval]*/ VARIANT_BOOL * pRetVal ) = 0;
      virtual HRESULT __stdcall Clear ( ) = 0;
      virtual HRESULT __stdcall Set (
        /*[in]*/ long left,
        /*[in]*/ long top,
        /*[in]*/ long right,
        /*[in]*/ long bottom ) = 0;
      virtual HRESULT __stdcall Copy (
        /*[in]*/ struct IRectangle * copyRect ) = 0;
      virtual HRESULT __stdcall Equals (
        /*[in]*/ struct IRectangle * rhsRect,
        /*[out,retval]*/ VARIANT_BOOL * pRetVal ) = 0;
      virtual HRESULT __stdcall get_left (
        /*[out,retval]*/ long * pRetVal ) = 0;
      virtual HRESULT __stdcall put_left (
        /*[in]*/ long pRetVal ) = 0;
      virtual HRESULT __stdcall get_top (
        /*[out,retval]*/ long * pRetVal ) = 0;
      virtual HRESULT __stdcall put_top (
        /*[in]*/ long pRetVal ) = 0;
      virtual HRESULT __stdcall get_right (
        /*[out,retval]*/ long * pRetVal ) = 0;
      virtual HRESULT __stdcall put_right (
        /*[in]*/ long pRetVal ) = 0;
      virtual HRESULT __stdcall get_bottom (
        /*[out,retval]*/ long * pRetVal ) = 0;
      virtual HRESULT __stdcall put_bottom (
        /*[in]*/ long pRetVal ) = 0;
};

struct __declspec(uuid("92efd367-80cc-4ddc-a841-ea000c531d39"))
ICaretEnhancements2 : ICaretEnhancements
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Location (
        /*[out,retval]*/ struct IRectangle * * pLocation ) = 0;
      virtual HRESULT __stdcall put_Location (
        /*[in]*/ struct IRectangle * pLocation ) = 0;
      virtual HRESULT __stdcall get_Visible (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_Visible (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
};

struct __declspec(uuid("bb0a2d5b-960f-4c98-beed-4454b73a36f1"))
ICaretEnhancements3 : ICaretEnhancements2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Scheme (
        /*[out,retval]*/ BSTR * pSchemeName ) = 0;
      virtual HRESULT __stdcall put_Scheme (
        /*[in]*/ BSTR pSchemeName ) = 0;
};

struct __declspec(uuid("a05e200e-7e70-4c7e-99ac-795bba608809"))
ICaretEnhancements4 : ICaretEnhancements3
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall Hide ( ) = 0;
};

struct __declspec(uuid("0370fad7-0e6b-46f1-a008-c6d689493fce"))
IColorEnhancements : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Enabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_Enabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
      virtual HRESULT __stdcall get_Type (
        /*[out,retval]*/ BSTR * pbstrType ) = 0;
      virtual HRESULT __stdcall put_Type (
        /*[in]*/ BSTR pbstrType ) = 0;
      virtual HRESULT __stdcall get_InvertBrightness (
        /*[out,retval]*/ VARIANT_BOOL * pbInvertBrightness ) = 0;
      virtual HRESULT __stdcall put_InvertBrightness (
        /*[in]*/ VARIANT_BOOL pbInvertBrightness ) = 0;
      virtual HRESULT __stdcall get_Brightness (
        /*[out,retval]*/ long * plBrightness ) = 0;
      virtual HRESULT __stdcall put_Brightness (
        /*[in]*/ long plBrightness ) = 0;
      virtual HRESULT __stdcall get_Contrast (
        /*[out,retval]*/ long * plContrast ) = 0;
      virtual HRESULT __stdcall put_Contrast (
        /*[in]*/ long plContrast ) = 0;
      virtual HRESULT __stdcall get_DyeColor (
        /*[out,retval]*/ long * plDyeColor ) = 0;
      virtual HRESULT __stdcall put_DyeColor (
        /*[in]*/ long plDyeColor ) = 0;
      virtual HRESULT __stdcall get_ForegroundColor (
        /*[out,retval]*/ long * plForegroundColor ) = 0;
      virtual HRESULT __stdcall put_ForegroundColor (
        /*[in]*/ long plForegroundColor ) = 0;
      virtual HRESULT __stdcall get_BackgroundColor (
        /*[out,retval]*/ long * plBackgroundColor ) = 0;
      virtual HRESULT __stdcall put_BackgroundColor (
        /*[in]*/ long plBackgroundColor ) = 0;
      virtual HRESULT __stdcall get_ColorToReplace (
        /*[out,retval]*/ long * plColorToReplace ) = 0;
      virtual HRESULT __stdcall put_ColorToReplace (
        /*[in]*/ long plColorToReplace ) = 0;
      virtual HRESULT __stdcall get_ReplaceWithColor (
        /*[out,retval]*/ long * plReplaceWithColor ) = 0;
      virtual HRESULT __stdcall put_ReplaceWithColor (
        /*[in]*/ long plReplaceWithColor ) = 0;
      virtual HRESULT __stdcall get_Bandwidth (
        /*[out,retval]*/ long * plBandwidth ) = 0;
      virtual HRESULT __stdcall put_Bandwidth (
        /*[in]*/ long plBandwidth ) = 0;
      virtual HRESULT __stdcall get_ColorToRemove (
        /*[out,retval]*/ long * plColorToRemove ) = 0;
      virtual HRESULT __stdcall put_ColorToRemove (
        /*[in]*/ long plColorToRemove ) = 0;
};

struct __declspec(uuid("9453cdaf-1e08-4861-a5ab-599dd5e7fd09"))
IColorEnhancements2 : IColorEnhancements
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Scheme (
        /*[out,retval]*/ BSTR * pSchemeName ) = 0;
      virtual HRESULT __stdcall put_Scheme (
        /*[in]*/ BSTR pSchemeName ) = 0;
};

struct __declspec(uuid("71c6bc10-ca7b-4812-8b1f-b64cb7a509e7"))
IDualMonitor : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Enabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_Enabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
      virtual HRESULT __stdcall get_Mode (
        /*[out,retval]*/ BSTR * pstrMode ) = 0;
      virtual HRESULT __stdcall put_Mode (
        /*[in]*/ BSTR pstrMode ) = 0;
};

struct __declspec(uuid("2e51ed2f-589a-4c74-b955-273ff8a04177"))
IFocusEnhancements : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Enabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_Enabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
};

struct __declspec(uuid("58041971-3a0b-4821-a436-6b9471fdfdc4"))
IFocusEnhancements2 : IFocusEnhancements
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall UpdateLocation (
        struct IRectangle * pRect ) = 0;
};

struct __declspec(uuid("9859118a-4c6f-41e8-a28d-a6e6c4480933"))
IFocusEnhancements3 : IFocusEnhancements2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Scheme (
        /*[out,retval]*/ BSTR * pSchemeName ) = 0;
      virtual HRESULT __stdcall put_Scheme (
        /*[in]*/ BSTR pSchemeName ) = 0;
};

struct __declspec(uuid("d90db93e-eef3-461b-9cd6-199bb252ef3b"))
IFocusEnhancements4 : IFocusEnhancements3
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall Hide ( ) = 0;
};

struct __declspec(uuid("0ee21611-d296-4c6d-8d28-87d7bfc626fa"))
IFontEnhancements : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Type (
        /*[out,retval]*/ BSTR * pType ) = 0;
      virtual HRESULT __stdcall put_Type (
        /*[in]*/ BSTR pType ) = 0;
};

struct __declspec(uuid("ffba1585-96aa-4be7-bf8e-7996be405683"))
IPower : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Level (
        /*[out,retval]*/ float * pfLevel ) = 0;
      virtual HRESULT __stdcall put_Level (
        /*[in]*/ float pfLevel ) = 0;
      virtual HRESULT __stdcall Increase ( ) = 0;
      virtual HRESULT __stdcall Decrease ( ) = 0;
};

struct __declspec(uuid("b9966bd6-5a59-4a20-b4d5-c97e70807527"))
IZoomWindow : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Enabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_Enabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
      virtual HRESULT __stdcall get_Type (
        /*[out,retval]*/ BSTR * pbstrType ) = 0;
      virtual HRESULT __stdcall put_Type (
        /*[in]*/ BSTR pbstrType ) = 0;
      virtual HRESULT __stdcall get_Location (
        /*[out,retval]*/ struct IRectangle * * ppRect ) = 0;
      virtual HRESULT __stdcall put_Location (
        /*[in]*/ struct IRectangle * ppRect ) = 0;
      virtual HRESULT __stdcall get_View (
        /*[out,retval]*/ struct IRectangle * * ppRect ) = 0;
      virtual HRESULT __stdcall put_View (
        /*[in]*/ struct IRectangle * ppRect ) = 0;
      virtual HRESULT __stdcall get_Power (
        /*[out,retval]*/ struct IPower * * ppPower ) = 0;
      virtual HRESULT __stdcall ViewToMouse ( ) = 0;
};

struct __declspec(uuid("41c19ac7-4d28-4d3b-a17f-704d0f1b3872"))
IPointerEnhancements : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Enabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_Enabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
};

struct __declspec(uuid("df2b31ee-a0a2-4f5d-8f29-969b91baf248"))
IPointerEnhancements2 : IPointerEnhancements
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Scheme (
        /*[out,retval]*/ BSTR * pSchemeName ) = 0;
      virtual HRESULT __stdcall put_Scheme (
        /*[in]*/ BSTR pSchemeName ) = 0;
};

struct __declspec(uuid("4dad7131-ee64-4c3d-82a6-db3763fbb60f"))
IPointerEnhancements3 : IPointerEnhancements2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_LocatorType (
        /*[out,retval]*/ BSTR * locatorTypeName ) = 0;
      virtual HRESULT __stdcall put_LocatorType (
        /*[in]*/ BSTR locatorTypeName ) = 0;
};

struct __declspec(uuid("9a59b310-74f6-4d43-b0ab-1f44da8268e0"))
ITracking : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Enabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_Enabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
      virtual HRESULT __stdcall JumpTo (
        BSTR strWhere ) = 0;
      virtual HRESULT __stdcall TrackTo (
        struct IRectangle * pRect ) = 0;
};

struct __declspec(uuid("0e890643-4d5b-4e20-8a72-80c8ad2511f9"))
ITracking2 : ITracking
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_AlertsEnabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_AlertsEnabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
      virtual HRESULT __stdcall get_ControlsEnabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_ControlsEnabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
      virtual HRESULT __stdcall get_MenusEnabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_MenusEnabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
      virtual HRESULT __stdcall get_MousePointerEnabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_MousePointerEnabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
      virtual HRESULT __stdcall get_TextCursorEnabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_TextCursorEnabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
      virtual HRESULT __stdcall get_ToolTipsEnabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_ToolTipsEnabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
      virtual HRESULT __stdcall get_WindowsEnabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_WindowsEnabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
};

struct __declspec(uuid("91b8c0cd-93cf-46f3-abba-04c61a13ba0c"))
IViewLocator : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Enabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_Enabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
};

struct __declspec(uuid("33fbe571-a41d-49cf-84c7-5e2207e37e98"))
IMagnification : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall CaptureScreen ( ) = 0;
      virtual HRESULT __stdcall get_CaretEnhancements (
        /*[out,retval]*/ struct ICaretEnhancements4 * * ppCaretEnhancements ) = 0;
      virtual HRESULT __stdcall get_ColorEnhancements (
        /*[out,retval]*/ struct IColorEnhancements2 * * ppColorEnhancements ) = 0;
      virtual HRESULT __stdcall get_DualMonitor (
        /*[out,retval]*/ struct IDualMonitor * * ppDualMonitor ) = 0;
      virtual HRESULT __stdcall get_FocusEnhancements (
        /*[out,retval]*/ struct IFocusEnhancements4 * * ppFocusEnhancements ) = 0;
      virtual HRESULT __stdcall get_FontEnhancements (
        /*[out,retval]*/ struct IFontEnhancements * * ppFontEnhancements ) = 0;
      virtual HRESULT __stdcall get_FreezeUsesPrimaryPower (
        /*[out,retval]*/ VARIANT_BOOL * pVariantBool ) = 0;
      virtual HRESULT __stdcall put_FreezeUsesPrimaryPower (
        /*[in]*/ VARIANT_BOOL pVariantBool ) = 0;
      virtual HRESULT __stdcall get_FreezeWindow (
        /*[out,retval]*/ struct IZoomWindow * * ppFreezeWindow ) = 0;
      virtual HRESULT __stdcall get_PointerEnhancements (
        /*[out,retval]*/ struct IPointerEnhancements3 * * ppPointerEnhancements ) = 0;
      virtual HRESULT __stdcall get_PrimaryWindow (
        /*[out,retval]*/ struct IZoomWindow * * ppPrimaryWindow ) = 0;
      virtual HRESULT __stdcall get_Tracking (
        /*[out,retval]*/ struct ITracking2 * * ppTracking ) = 0;
      virtual HRESULT __stdcall get_ViewLocator (
        /*[out,retval]*/ struct IViewLocator * * ppViewLocator ) = 0;
};

struct __declspec(uuid("1a1f44c1-83b2-4d12-b6fe-629751c134ec"))
IScreenHighlight : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Color (
        /*[out,retval]*/ long * plColor ) = 0;
      virtual HRESULT __stdcall put_Color (
        /*[in]*/ long plColor ) = 0;
      virtual HRESULT __stdcall get_Enabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnable ) = 0;
      virtual HRESULT __stdcall put_Enabled (
        /*[in]*/ VARIANT_BOOL pbEnable ) = 0;
      virtual HRESULT __stdcall get_Invert (
        /*[out,retval]*/ VARIANT_BOOL * pbInvert ) = 0;
      virtual HRESULT __stdcall put_Invert (
        /*[in]*/ VARIANT_BOOL pbInvert ) = 0;
      virtual HRESULT __stdcall get_Location (
        /*[out,retval]*/ struct IRectangle * * pLocation ) = 0;
      virtual HRESULT __stdcall put_Location (
        /*[in]*/ struct IRectangle * pLocation ) = 0;
      virtual HRESULT __stdcall get_Mode (
        /*[out,retval]*/ long * plMode ) = 0;
      virtual HRESULT __stdcall put_Mode (
        /*[in]*/ long plMode ) = 0;
      virtual HRESULT __stdcall get_Padding (
        /*[out,retval]*/ long * plPadding ) = 0;
      virtual HRESULT __stdcall put_Padding (
        /*[in]*/ long plPadding ) = 0;
      virtual HRESULT __stdcall get_Shape (
        /*[out,retval]*/ long * plShape ) = 0;
      virtual HRESULT __stdcall put_Shape (
        /*[in]*/ long plShape ) = 0;
      virtual HRESULT __stdcall get_Thickness (
        /*[out,retval]*/ long * plThickness ) = 0;
      virtual HRESULT __stdcall put_Thickness (
        /*[in]*/ long plThickness ) = 0;
      virtual HRESULT __stdcall get_Timeout (
        /*[out,retval]*/ long * plTimeout ) = 0;
      virtual HRESULT __stdcall put_Timeout (
        /*[in]*/ long plTimeout ) = 0;
      virtual HRESULT __stdcall get_Transparency (
        /*[out,retval]*/ long * plTransparency ) = 0;
      virtual HRESULT __stdcall put_Transparency (
        /*[in]*/ long plTransparency ) = 0;
};

struct __declspec(uuid("eb53ca25-96d6-4978-bc65-4c3b2118cee5"))
IScreenHighlight2 : IScreenHighlight
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall UseFocusEnhancementSettings ( ) = 0;
};

struct __declspec(uuid("b8ee8cbb-6357-44ef-a024-0b756d0d7730"))
IMagnification2 : IMagnification
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_ScreenHighlight (
        /*[out,retval]*/ struct IScreenHighlight2 * * ppScreenHighlight ) = 0;
};

struct __declspec(uuid("050e0e11-3d0a-4f6e-a634-c2270e30dc1b"))
ICCTV : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Enabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnable ) = 0;
      virtual HRESULT __stdcall put_Enabled (
        /*[in]*/ VARIANT_BOOL pbEnable ) = 0;
      virtual HRESULT __stdcall SetResolution (
        /*[in]*/ long width,
        /*[in]*/ long height ) = 0;
      virtual HRESULT __stdcall SetLocation (
        /*[in]*/ long left,
        /*[in]*/ long top,
        /*[in]*/ long right,
        /*[in]*/ long bottom ) = 0;
      virtual HRESULT __stdcall SetStreamsOffset (
        /*[in]*/ long x,
        /*[in]*/ long y ) = 0;
      virtual HRESULT __stdcall CenterStream ( ) = 0;
};

struct __declspec(uuid("7fecb1f1-c6d4-4f80-87b4-06dcaabebf57"))
IMagnification3 : IMagnification2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_CCTV (
        /*[out,retval]*/ struct ICCTV * * ppCCTV ) = 0;
};

struct __declspec(uuid("e9bed2bf-8834-49f9-ad4c-12c3cf7373ad"))
IPoint : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall Clear ( ) = 0;
      virtual HRESULT __stdcall Set (
        /*[in]*/ long x,
        /*[in]*/ long y ) = 0;
      virtual HRESULT __stdcall Copy (
        /*[in]*/ struct IPoint * copyPoint ) = 0;
      virtual HRESULT __stdcall Equals (
        /*[in]*/ struct IPoint * rhsPoint,
        /*[out,retval]*/ VARIANT_BOOL * pRetVal ) = 0;
      virtual HRESULT __stdcall get_x (
        /*[out,retval]*/ long * pRetVal ) = 0;
      virtual HRESULT __stdcall put_x (
        /*[in]*/ long pRetVal ) = 0;
      virtual HRESULT __stdcall get_y (
        /*[out,retval]*/ long * pRetVal ) = 0;
      virtual HRESULT __stdcall put_y (
        /*[in]*/ long pRetVal ) = 0;
};

struct __declspec(uuid("4c2662b3-4cf7-4b05-b0b0-53ae74ee8d5d"))
IMouse : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Location (
        /*[out,retval]*/ struct IPoint * * pPoint ) = 0;
      virtual HRESULT __stdcall put_Location (
        /*[in]*/ struct IPoint * pPoint ) = 0;
      virtual HRESULT __stdcall Click (
        /*[in]*/ BSTR pButton ) = 0;
      virtual HRESULT __stdcall DoubleClick (
        /*[in]*/ BSTR pButton ) = 0;
      virtual HRESULT __stdcall MoveToView ( ) = 0;
};

struct __declspec(uuid("c4c5a470-4f53-4bbf-a534-ba88e9fbbe5f"))
IAppReader : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall Start ( ) = 0;
      virtual HRESULT __stdcall StartAtPoint (
        struct IPoint * pPoint ) = 0;
      virtual HRESULT __stdcall Stop ( ) = 0;
};

struct __declspec(uuid("1203b332-4ef0-41fd-bc24-763503b8dc90"))
IMouseEcho : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Mode (
        /*[out,retval]*/ BSTR * pstrMode ) = 0;
      virtual HRESULT __stdcall put_Mode (
        /*[in]*/ BSTR pstrMode ) = 0;
};

struct __declspec(uuid("0472df6c-835a-4180-a35a-a5608fa2fce8"))
IMouseEcho2 : IMouseEcho
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Scope (
        /*[out,retval]*/ BSTR * pstrMode ) = 0;
      virtual HRESULT __stdcall put_Scope (
        /*[in]*/ BSTR pstrMode ) = 0;
      virtual HRESULT __stdcall get_Time (
        /*[out,retval]*/ float * Time ) = 0;
      virtual HRESULT __stdcall put_Time (
        /*[in]*/ float Time ) = 0;
};

struct __declspec(uuid("cb508dd4-5076-4b3c-b792-629d6c37af41"))
IReadingZoneObject : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Name (
        /*[out,retval]*/ BSTR * pstrName ) = 0;
      virtual HRESULT __stdcall put_Name (
        /*[in]*/ BSTR pstrName ) = 0;
      virtual HRESULT __stdcall get_Location (
        /*[out,retval]*/ struct IRectangle * * ppLocation ) = 0;
      virtual HRESULT __stdcall put_Location (
        /*[in]*/ struct IRectangle * ppLocation ) = 0;
      virtual HRESULT __stdcall get_ApplicationName (
        /*[out,retval]*/ BSTR * pstrAppName ) = 0;
      virtual HRESULT __stdcall put_ApplicationName (
        /*[in]*/ BSTR pstrAppName ) = 0;
      virtual HRESULT __stdcall get_Anchor (
        /*[out,retval]*/ BSTR * pstrAnchor ) = 0;
      virtual HRESULT __stdcall put_Anchor (
        /*[in]*/ BSTR pstrAnchor ) = 0;
      virtual HRESULT __stdcall get_Action (
        /*[out,retval]*/ BSTR * pstrAction ) = 0;
      virtual HRESULT __stdcall put_Action (
        /*[in]*/ BSTR pstrAction ) = 0;
      virtual HRESULT __stdcall get_HighlightTime (
        /*[out,retval]*/ float * pfSeconds ) = 0;
      virtual HRESULT __stdcall put_HighlightTime (
        /*[in]*/ float pfSeconds ) = 0;
      virtual HRESULT __stdcall get_ReturnToPreviousLocation (
        /*[out,retval]*/ VARIANT_BOOL * pbReturns ) = 0;
      virtual HRESULT __stdcall put_ReturnToPreviousLocation (
        /*[in]*/ VARIANT_BOOL pbReturns ) = 0;
      virtual HRESULT __stdcall get_DimAreaOutside (
        /*[out,retval]*/ VARIANT_BOOL * pbDims ) = 0;
      virtual HRESULT __stdcall put_DimAreaOutside (
        /*[in]*/ VARIANT_BOOL pbDims ) = 0;
      virtual HRESULT __stdcall get_ZoneID (
        /*[out,retval]*/ long * pId ) = 0;
};

struct __declspec(uuid("a0a71491-2b73-43f3-9e6b-5a9fddddc3d1"))
IReadingZones : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall CreateZone (
        /*[in]*/ struct IReadingZoneObject * pZone ) = 0;
      virtual HRESULT __stdcall DeleteZone (
        /*[in]*/ BSTR ApplicationName,
        /*[in]*/ long ZoneID ) = 0;
      virtual HRESULT __stdcall ToggleZone (
        /*[in]*/ long lZoneNum ) = 0;
      virtual HRESULT __stdcall NextZone ( ) = 0;
      virtual HRESULT __stdcall PreviousZone ( ) = 0;
};

struct __declspec(uuid("865c25b5-9a75-4e41-b182-dca1768255e3"))
ITypingEcho : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Mode (
        /*[out,retval]*/ BSTR * pstrMode ) = 0;
      virtual HRESULT __stdcall put_Mode (
        /*[in]*/ BSTR pstrMode ) = 0;
};

struct __declspec(uuid("7f5432aa-9729-4fd3-a783-2c02fabe5b86"))
IVerbosity : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall GetSetting (
        /*[in]*/ BSTR bstrLevel,
        /*[in]*/ BSTR bstrValueName,
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall SetSetting (
        /*[in]*/ BSTR bstrLevel,
        /*[in]*/ BSTR bstrValueName,
        /*[in]*/ VARIANT_BOOL bEnabled ) = 0;
      virtual HRESULT __stdcall get_Level (
        /*[out,retval]*/ BSTR * pstrLevel ) = 0;
      virtual HRESULT __stdcall put_Level (
        /*[in]*/ BSTR pstrLevel ) = 0;
};

struct __declspec(uuid("cde9e8a8-03a7-4413-86a3-aca30f305ac1"))
IReader : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_AppReader (
        /*[out,retval]*/ struct IAppReader * * ppAppReader ) = 0;
      virtual HRESULT __stdcall get_MouseEcho (
        /*[out,retval]*/ struct IMouseEcho2 * * ppMouseEcho ) = 0;
      virtual HRESULT __stdcall get_ReadingZones (
        /*[out,retval]*/ struct IReadingZones * * ppReadingZones ) = 0;
      virtual HRESULT __stdcall get_TypingEcho (
        /*[out,retval]*/ struct ITypingEcho * * ppTypingEcho ) = 0;
      virtual HRESULT __stdcall get_Verbosity (
        /*[out,retval]*/ struct IVerbosity * * ppVerbosity ) = 0;
};

struct __declspec(uuid("bfff5140-ba03-40b0-8131-ec64673bc735"))
IProgramEcho : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_AlertsEnabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_AlertsEnabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
      virtual HRESULT __stdcall get_ControlsEnabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_ControlsEnabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
      virtual HRESULT __stdcall get_MenusEnabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_MenusEnabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
      virtual HRESULT __stdcall get_TextCursorEchosLine (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_TextCursorEchosLine (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
      virtual HRESULT __stdcall get_TextCursorEnabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_TextCursorEnabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
      virtual HRESULT __stdcall get_ToolTipsEnabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_ToolTipsEnabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
      virtual HRESULT __stdcall get_WindowTitlesEnabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall put_WindowTitlesEnabled (
        /*[in]*/ VARIANT_BOOL pbEnabled ) = 0;
};

struct __declspec(uuid("5f41aadc-84dc-445d-bb22-0fde09b95e91"))
IReader2 : IReader
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_ProgramEcho (
        /*[out,retval]*/ struct IProgramEcho * * ppProgramEcho ) = 0;
};

struct __declspec(uuid("8423fbeb-feaf-4248-9638-156a7543ea91"))
IDocReader : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall Start ( ) = 0;
      virtual HRESULT __stdcall Stop ( ) = 0;
};

struct __declspec(uuid("2aeb500e-85ad-4808-836b-2f1512697966"))
IRecorder : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall Start ( ) = 0;
};

struct __declspec(uuid("129e7a0e-9e23-469d-a2ca-de3baecaf45d"))
IReader3 : IReader2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_DocReader (
        /*[out,retval]*/ struct IDocReader * * ppDocReader ) = 0;
      virtual HRESULT __stdcall get_Recorder (
        /*[out,retval]*/ struct IRecorder * * ppRecorder ) = 0;
};

struct __declspec(uuid("0c32cc2f-22f4-4980-a4d8-6cda1f1b4d8d"))
IReader4 : IReader3
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_MouseEcho1 (
        /*[out,retval]*/ struct IMouseEcho * * ppMouseEcho ) = 0;
      virtual HRESULT __stdcall get_MouseEcho2 (
        /*[out,retval]*/ struct IMouseEcho2 * * ppMouseEcho ) = 0;
};

struct __declspec(uuid("fa636707-c09a-4fd9-8a1b-838a5a505a4c"))
IScriptInformation : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_ScriptName (
        /*[out,retval]*/ BSTR * pbstrData ) = 0;
      virtual HRESULT __stdcall put_ScriptName (
        /*[in]*/ BSTR pbstrData ) = 0;
      virtual HRESULT __stdcall get_Version (
        /*[out,retval]*/ BSTR * pbstrData ) = 0;
      virtual HRESULT __stdcall put_Version (
        /*[in]*/ BSTR pbstrData ) = 0;
      virtual HRESULT __stdcall get_Date (
        /*[out,retval]*/ BSTR * pbstrData ) = 0;
      virtual HRESULT __stdcall put_Date (
        /*[in]*/ BSTR pbstrData ) = 0;
      virtual HRESULT __stdcall get_Author (
        /*[out,retval]*/ BSTR * pbstrData ) = 0;
      virtual HRESULT __stdcall put_Author (
        /*[in]*/ BSTR pbstrData ) = 0;
      virtual HRESULT __stdcall get_Address1 (
        /*[out,retval]*/ BSTR * pbstrData ) = 0;
      virtual HRESULT __stdcall put_Address1 (
        /*[in]*/ BSTR pbstrData ) = 0;
      virtual HRESULT __stdcall get_Address2 (
        /*[out,retval]*/ BSTR * pbstrData ) = 0;
      virtual HRESULT __stdcall put_Address2 (
        /*[in]*/ BSTR pbstrData ) = 0;
      virtual HRESULT __stdcall get_Address3 (
        /*[out,retval]*/ BSTR * pbstrData ) = 0;
      virtual HRESULT __stdcall put_Address3 (
        /*[in]*/ BSTR pbstrData ) = 0;
      virtual HRESULT __stdcall get_Email (
        /*[out,retval]*/ BSTR * pbstrData ) = 0;
      virtual HRESULT __stdcall put_Email (
        /*[in]*/ BSTR pbstrData ) = 0;
      virtual HRESULT __stdcall get_Website (
        /*[out,retval]*/ BSTR * pbstrData ) = 0;
      virtual HRESULT __stdcall put_Website (
        /*[in]*/ BSTR pbstrData ) = 0;
      virtual HRESULT __stdcall get_Phone (
        /*[out,retval]*/ BSTR * pbstrData ) = 0;
      virtual HRESULT __stdcall put_Phone (
        /*[in]*/ BSTR pbstrData ) = 0;
      virtual HRESULT __stdcall get_Description (
        /*[out,retval]*/ BSTR * pbstrData ) = 0;
      virtual HRESULT __stdcall put_Description (
        /*[in]*/ BSTR pbstrData ) = 0;
      virtual HRESULT __stdcall get_Copyright (
        /*[out,retval]*/ BSTR * pbstrData ) = 0;
      virtual HRESULT __stdcall put_Copyright (
        /*[in]*/ BSTR pbstrData ) = 0;
};

struct __declspec(uuid("ff065601-dc5c-49ad-ab8d-58325885be0b"))
IScriptConfiguration : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall RegisterScriptFile (
        /*[in]*/ BSTR bsFilePath ) = 0;
      virtual HRESULT __stdcall RegisterScriptComponent (
        /*[in]*/ BSTR bsProgID ) = 0;
      virtual HRESULT __stdcall UnregisterScript (
        /*[in]*/ BSTR bstrName ) = 0;
      virtual HRESULT __stdcall ScriptRegistered (
        /*[in]*/ BSTR bstrName,
        /*[out,retval]*/ VARIANT_BOOL * pbRegistered ) = 0;
      virtual HRESULT __stdcall GetFirstScript (
        /*[out,retval]*/ BSTR * pbstrName ) = 0;
      virtual HRESULT __stdcall GetNextScript (
        /*[in]*/ BSTR bstrName,
        /*[out,retval]*/ BSTR * pbstrNext ) = 0;
      virtual HRESULT __stdcall GetScriptType (
        /*[in]*/ BSTR bstrName,
        /*[out,retval]*/ unsigned long * dwType ) = 0;
      virtual HRESULT __stdcall ScriptInitialized (
        /*[in]*/ BSTR bstrName,
        /*[out,retval]*/ VARIANT_BOOL * pbInitialized ) = 0;
      virtual HRESULT __stdcall ChangeScriptLoadOrder (
        /*[in]*/ BSTR bstrScript,
        /*[in]*/ int iPosChange ) = 0;
      virtual HRESULT __stdcall EnableScript (
        /*[in]*/ BSTR bstrScript ) = 0;
      virtual HRESULT __stdcall DisableScript (
        /*[in]*/ BSTR bstrScript ) = 0;
      virtual HRESULT __stdcall ScriptEnabled (
        /*[in]*/ BSTR bstrScript,
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall GetScriptFileInformation (
        /*[in]*/ BSTR bstrScript,
        /*[out,retval]*/ struct IScriptInformation * * pScriptInformation ) = 0;
      virtual HRESULT __stdcall GetScriptComponentInformation (
        /*[in]*/ BSTR bstrScript,
        /*[out,retval]*/ struct IScriptInformation * * pScriptInformation ) = 0;
      virtual HRESULT __stdcall get_RequireAdmin (
        /*[out,retval]*/ VARIANT_BOOL * pbRequireAdmin ) = 0;
      virtual HRESULT __stdcall put_RequireAdmin (
        /*[in]*/ VARIANT_BOOL pbRequireAdmin ) = 0;
      virtual HRESULT __stdcall SetScriptInformation (
        /*[in]*/ BSTR bstrScript,
        /*[in]*/ struct IScriptInformation * pScriptInformation ) = 0;
};

struct __declspec(uuid("627f824e-cf7c-43d9-a4cf-1c139a934a2e"))
IScriptConfiguration2 : IScriptConfiguration
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall ScriptIsGlobal (
        /*[in]*/ BSTR strScript,
        /*[out,retval]*/ VARIANT_BOOL * pbHasUI ) = 0;
      virtual HRESULT __stdcall ScriptHasUI (
        /*[in]*/ BSTR strScript,
        /*[out,retval]*/ VARIANT_BOOL * pbHasUI ) = 0;
      virtual HRESULT __stdcall ScriptDisplayUI (
        /*[in]*/ BSTR strScript ) = 0;
};

struct __declspec(uuid("ee7b5cc9-bf3e-493d-aed4-a0a0a10a9a8c"))
IZoomTextSettings : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_UiCulture (
        /*[out,retval]*/ BSTR * pUiCulture ) = 0;
};

struct __declspec(uuid("e874a180-d7c9-4b21-a638-982d36f5ea7e"))
IZoomTextSettings2 : IZoomTextSettings
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_ProgramFolder (
        /*[out,retval]*/ BSTR * pbstrValue ) = 0;
      virtual HRESULT __stdcall get_ScriptDataFolder (
        /*[out,retval]*/ BSTR * pbstrValue ) = 0;
      virtual HRESULT __stdcall get_ScriptsFolder (
        /*[out,retval]*/ BSTR * pbstrValue ) = 0;
};

struct __declspec(uuid("51b35190-807c-4ac8-b74f-3a3fd83e6f86"))
IZoomTextSettings3 : IZoomTextSettings2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_ProductType (
        /*[out,retval]*/ unsigned long * pdwType ) = 0;
      virtual HRESULT __stdcall get_MyScriptsFolder (
        /*[out,retval]*/ BSTR * pbstrValue ) = 0;
      virtual HRESULT __stdcall get_SharedScriptsFolder (
        /*[out,retval]*/ BSTR * pbstrValue ) = 0;
      virtual HRESULT __stdcall get_SampleScriptsFolder (
        /*[out,retval]*/ BSTR * pbstrValue ) = 0;
      virtual HRESULT __stdcall GetScriptSetting (
        /*[in]*/ BSTR bstrName,
        /*[in]*/ BSTR bstrDefaultValue,
        /*[out,retval]*/ BSTR * pbstrValue ) = 0;
      virtual HRESULT __stdcall SetScriptSetting (
        /*[in]*/ BSTR bstrName,
        /*[in]*/ BSTR bstrValue ) = 0;
};

struct __declspec(uuid("84c39c47-0cfb-43a8-b88e-0c6662000877"))
IZoomTextSettings4 : IZoomTextSettings3
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_CurrentConfigurationFile (
        /*[out,retval]*/ BSTR * pbstrValue ) = 0;
};

struct __declspec(uuid("c8050fe3-1249-4b16-a8c9-81dd21b10ad5"))
IZoomTextSettings5 : IZoomTextSettings4
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall GetConfigurationSetting (
        /*[in]*/ BSTR bstrFile,
        /*[in]*/ BSTR bstrSection,
        /*[in]*/ BSTR bstrName,
        /*[in]*/ BSTR bstrDefaultValue,
        /*[out,retval]*/ BSTR * pbstrValue ) = 0;
      virtual HRESULT __stdcall SetConfigurationSetting (
        /*[in]*/ BSTR bstrFile,
        /*[in]*/ BSTR bstrSection,
        /*[in]*/ BSTR bstrName,
        /*[in]*/ BSTR bstrValue ) = 0;
};

struct __declspec(uuid("e73eaf69-0892-48f5-a078-53d37a3b6555"))
IZoomTextSettings6 : IZoomTextSettings5
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall LoadDefaultConfiguration ( ) = 0;
      virtual HRESULT __stdcall SaveAsDefaultConfiguration ( ) = 0;
      virtual HRESULT __stdcall RestoreFactoryDefaults ( ) = 0;
      virtual HRESULT __stdcall get_TaskbarSetting (
        /*[out,retval]*/ BSTR * pSchemeName ) = 0;
      virtual HRESULT __stdcall put_TaskbarSetting (
        /*[in]*/ BSTR pSchemeName ) = 0;
};

struct __declspec(uuid("a2fbf963-0748-4266-a04b-8c54466126d5"))
IVoice : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Active (
        /*[out,retval]*/ VARIANT_BOOL * pbActive ) = 0;
      virtual HRESULT __stdcall put_Active (
        /*[in]*/ VARIANT_BOOL pbActive ) = 0;
      virtual HRESULT __stdcall get_LanguageID (
        /*[out,retval]*/ long * pnLanguageID ) = 0;
      virtual HRESULT __stdcall get_Mute (
        /*[out,retval]*/ VARIANT_BOOL * pbMute ) = 0;
      virtual HRESULT __stdcall put_Mute (
        /*[in]*/ VARIANT_BOOL pbMute ) = 0;
      virtual HRESULT __stdcall get_Pitch (
        /*[out,retval]*/ long * pnPitch ) = 0;
      virtual HRESULT __stdcall put_Pitch (
        /*[in]*/ long pnPitch ) = 0;
      virtual HRESULT __stdcall get_PitchSupported (
        /*[out,retval]*/ VARIANT_BOOL * pbSupported ) = 0;
      virtual HRESULT __stdcall get_ProductName (
        /*[out,retval]*/ BSTR * pbstrProductName ) = 0;
      virtual HRESULT __stdcall get_Rate (
        /*[out,retval]*/ long * pnRate ) = 0;
      virtual HRESULT __stdcall put_Rate (
        /*[in]*/ long pnRate ) = 0;
      virtual HRESULT __stdcall get_RateSupported (
        /*[out,retval]*/ VARIANT_BOOL * pbSupported ) = 0;
      virtual HRESULT __stdcall get_Speaking (
        /*[out,retval]*/ VARIANT_BOOL * pbSpeaking ) = 0;
      virtual HRESULT __stdcall get_VoiceName (
        /*[out,retval]*/ BSTR * pbstrVoiceName ) = 0;
      virtual HRESULT __stdcall get_Volume (
        /*[out,retval]*/ long * pnVolume ) = 0;
      virtual HRESULT __stdcall put_Volume (
        /*[in]*/ long pnVolume ) = 0;
      virtual HRESULT __stdcall get_VolumeSupported (
        /*[out,retval]*/ VARIANT_BOOL * pbSupported ) = 0;
      virtual HRESULT __stdcall get_SpellMode (
        /*[out,retval]*/ VARIANT_BOOL * pbSpell ) = 0;
      virtual HRESULT __stdcall put_SpellMode (
        /*[in]*/ VARIANT_BOOL pbSpell ) = 0;
      virtual HRESULT __stdcall get_SpeakImmediate (
        /*[out,retval]*/ VARIANT_BOOL * pbImmediate ) = 0;
      virtual HRESULT __stdcall put_SpeakImmediate (
        /*[in]*/ VARIANT_BOOL pbImmediate ) = 0;
      virtual HRESULT __stdcall get_AllowInterrupt (
        /*[out,retval]*/ VARIANT_BOOL * pbInterrupt ) = 0;
      virtual HRESULT __stdcall put_AllowInterrupt (
        /*[in]*/ VARIANT_BOOL pbInterrupt ) = 0;
      virtual HRESULT __stdcall Speak (
        /*[in]*/ BSTR bstrText ) = 0;
      virtual HRESULT __stdcall Stop ( ) = 0;
      virtual HRESULT __stdcall SpeakEvent (
        /*[in]*/ IDispatch * pSpeechEventObject ) = 0;
};

struct __declspec(uuid("e9ef732f-25ef-4d19-a0d2-fe8f6d3a1bbb"))
IObjectCollection : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Size (
        /*[out,retval]*/ long * pSize ) = 0;
      virtual HRESULT __stdcall get_First (
        /*[out,retval]*/ IDispatch * * ppObject ) = 0;
      virtual HRESULT __stdcall get_Last (
        /*[out,retval]*/ IDispatch * * ppObject ) = 0;
      virtual HRESULT __stdcall Next (
        /*[in]*/ VARIANT vCurrent,
        /*[out,retval]*/ IDispatch * * ppObject ) = 0;
      virtual HRESULT __stdcall Previous (
        /*[in]*/ VARIANT vCurrent,
        /*[out,retval]*/ IDispatch * * ppObject ) = 0;
};

struct __declspec(uuid("b7271c8c-3a94-4831-883b-81ba18b87664"))
ISpeech : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_CurrentVoice (
        /*[out,retval]*/ struct IVoice * * ppVoice ) = 0;
      virtual HRESULT __stdcall put_CurrentVoice (
        /*[in]*/ struct IVoice * ppVoice ) = 0;
      virtual HRESULT __stdcall get_Enabled (
        /*[out,retval]*/ VARIANT_BOOL * pbEnabled ) = 0;
      virtual HRESULT __stdcall Voices (
        /*[out,retval]*/ struct IObjectCollection * * ppVoiceCollection ) = 0;
};

struct __declspec(uuid("c7149863-61d3-422f-aa2c-0dca654914d5"))
ISpeaker : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_LanguageID (
        /*[out,retval]*/ long * pnLanguageID ) = 0;
      virtual HRESULT __stdcall get_Mute (
        /*[out,retval]*/ VARIANT_BOOL * pbMute ) = 0;
      virtual HRESULT __stdcall put_Mute (
        /*[in]*/ VARIANT_BOOL pbMute ) = 0;
      virtual HRESULT __stdcall get_Pitch (
        /*[out,retval]*/ long * pnPitch ) = 0;
      virtual HRESULT __stdcall put_Pitch (
        /*[in]*/ long pnPitch ) = 0;
      virtual HRESULT __stdcall get_PitchSupported (
        /*[out,retval]*/ VARIANT_BOOL * pbSupported ) = 0;
      virtual HRESULT __stdcall get_ProductName (
        /*[out,retval]*/ BSTR * pbstrProductName ) = 0;
      virtual HRESULT __stdcall get_Rate (
        /*[out,retval]*/ long * pnRate ) = 0;
      virtual HRESULT __stdcall put_Rate (
        /*[in]*/ long pnRate ) = 0;
      virtual HRESULT __stdcall get_RateSupported (
        /*[out,retval]*/ VARIANT_BOOL * pbSupported ) = 0;
      virtual HRESULT __stdcall get_RateMaximum (
        /*[out,retval]*/ long * pnRateMaximum ) = 0;
      virtual HRESULT __stdcall get_RateMinimum (
        /*[out,retval]*/ long * pnRateMinimum ) = 0;
      virtual HRESULT __stdcall get_RateIsWPM (
        /*[out,retval]*/ VARIANT_BOOL * pbRateIsWPM ) = 0;
      virtual HRESULT __stdcall get_Speaking (
        /*[out,retval]*/ VARIANT_BOOL * pbSpeaking ) = 0;
      virtual HRESULT __stdcall get_VoiceName (
        /*[out,retval]*/ BSTR * pbstrVoiceName ) = 0;
      virtual HRESULT __stdcall get_Volume (
        /*[out,retval]*/ long * pnVolume ) = 0;
      virtual HRESULT __stdcall put_Volume (
        /*[in]*/ long pnVolume ) = 0;
      virtual HRESULT __stdcall get_VolumeSupported (
        /*[out,retval]*/ VARIANT_BOOL * pbSupported ) = 0;
      virtual HRESULT __stdcall get_SpellMode (
        /*[out,retval]*/ VARIANT_BOOL * pbSpell ) = 0;
      virtual HRESULT __stdcall put_SpellMode (
        /*[in]*/ VARIANT_BOOL pbSpell ) = 0;
      virtual HRESULT __stdcall get_SpeakImmediate (
        /*[out,retval]*/ VARIANT_BOOL * pbImmediate ) = 0;
      virtual HRESULT __stdcall put_SpeakImmediate (
        /*[in]*/ VARIANT_BOOL pbImmediate ) = 0;
      virtual HRESULT __stdcall get_AllowInterrupt (
        /*[out,retval]*/ VARIANT_BOOL * pbInterrupt ) = 0;
      virtual HRESULT __stdcall put_AllowInterrupt (
        /*[in]*/ VARIANT_BOOL pbInterrupt ) = 0;
      virtual HRESULT __stdcall get_Handle (
        /*[out,retval]*/ unsigned long * pdwSpeakerHandle ) = 0;
      virtual HRESULT __stdcall get_FileOutputStatus (
        /*[out,retval]*/ long * plStatus ) = 0;
      virtual HRESULT __stdcall get_SpeakStatus (
        /*[out,retval]*/ long * plStatus ) = 0;
      virtual HRESULT __stdcall Speak (
        /*[in]*/ BSTR bstrText,
        /*[in]*/ VARIANT varDoneEvent = vtMissing ) = 0;
      virtual HRESULT __stdcall Stop ( ) = 0;
      virtual HRESULT __stdcall OutputToWaveFile (
        /*[in]*/ BSTR bstrText,
        /*[in]*/ BSTR bstrFile,
        /*[in]*/ VARIANT varDoneEvent = vtMissing ) = 0;
      virtual HRESULT __stdcall CancelOutputToWaveFile ( ) = 0;
};

struct __declspec(uuid("cd16491d-29de-4cb2-a4d9-2ad423fe3c6e"))
ISpeech2 : ISpeech
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall FindVoice (
        /*[in]*/ BSTR bstrProductName,
        /*[in]*/ BSTR bstrVoiceName,
        /*[out,retval]*/ struct IVoice * * ppVoice ) = 0;
      virtual HRESULT __stdcall CreateSpeaker (
        /*[in]*/ struct IVoice * pVoice,
        /*[out,retval]*/ struct ISpeaker * * ppSpeaker ) = 0;
      virtual HRESULT __stdcall DeleteSpeaker (
        /*[in]*/ struct ISpeaker * pSpeaker ) = 0;
};

#pragma pack(push, 4)

struct tagAHOIOBJECTID
{
    short Provider;
    short Type;
    long Id;
};

#pragma pack(pop)

struct __declspec(uuid("729772a3-83e7-4d86-a30c-780c24d0bb6c"))
IScriptManager : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall DetachScriptTrigger (
        /*[in]*/ BSTR bstrTriggerPoint,
        /*[in]*/ BSTR bstrScriptName ) = 0;
      virtual HRESULT __stdcall DetachScriptTriggersFromTriggerPoint (
        /*[in]*/ BSTR bstrTriggerPoint ) = 0;
      virtual HRESULT __stdcall DetachScriptTriggersFromAllTriggerPoints ( ) = 0;
      virtual HRESULT __stdcall DisableScriptTrigger (
        /*[in]*/ BSTR bstrTriggerPoint,
        /*[in]*/ BSTR bstrScriptName ) = 0;
      virtual HRESULT __stdcall DisableScriptTriggerPoint (
        /*[in]*/ BSTR bstrTriggerPoint ) = 0;
      virtual HRESULT __stdcall DisableScriptTriggerPoints ( ) = 0;
      virtual HRESULT __stdcall EnableScriptTrigger (
        /*[in]*/ BSTR bstrTriggerPoint,
        /*[in]*/ BSTR bstrScriptName ) = 0;
      virtual HRESULT __stdcall EnableScriptTriggerPoint (
        /*[in]*/ BSTR bstrTriggerName ) = 0;
      virtual HRESULT __stdcall EnableScriptTriggerPoints ( ) = 0;
      virtual HRESULT __stdcall GetTriggerPointFilterData (
        /*[in]*/ BSTR bstrTriggerPoint,
        /*[out,retval]*/ struct IEventDefinition * * pTriggerPointData ) = 0;
      virtual HRESULT __stdcall GetTriggerFilterData (
        /*[in]*/ BSTR bstrTriggerPoint,
        /*[in]*/ BSTR bstrScriptName,
        /*[out,retval]*/ struct IEventDefinition * * pTriggerPointData ) = 0;
      virtual HRESULT __stdcall EnableTriggersForScript (
        /*[in]*/ BSTR bstrScript ) = 0;
      virtual HRESULT __stdcall DisableTriggersForScript (
        /*[in]*/ BSTR bstrScript ) = 0;
};

struct __declspec(uuid("de188a1c-7426-46f4-95e2-4004a5f664d9"))
IZoomText : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_ActiveToolMode (
        /*[out,retval]*/ BSTR * pstrToolMode ) = 0;
      virtual HRESULT __stdcall get_AhoiManager (
        /*[out,retval]*/ struct IAhoiManager2 * * ppObj ) = 0;
      virtual HRESULT __stdcall CreateObject (
        /*[in]*/ BSTR bstrObjName,
        /*[out,retval]*/ IUnknown * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Enabled (
        /*[out,retval]*/ VARIANT_BOOL * pEnabled ) = 0;
      virtual HRESULT __stdcall put_Enabled (
        /*[in]*/ VARIANT_BOOL pEnabled ) = 0;
      virtual HRESULT __stdcall get_EventManager (
        /*[out,retval]*/ struct IEventManager2 * * ppObj ) = 0;
      virtual HRESULT __stdcall GetEventData (
        /*[in]*/ BSTR bstrDataHandle,
        /*[out,retval]*/ IUnknown * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Hotkeys (
        /*[out,retval]*/ struct IHotkeys2 * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Keyboard (
        /*[out,retval]*/ struct IKeyboard * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Magnification (
        /*[out,retval]*/ struct IMagnification3 * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Mouse (
        /*[out,retval]*/ struct IMouse * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Reader (
        /*[out,retval]*/ struct IReader4 * * ppObj ) = 0;
      virtual HRESULT __stdcall get_ScriptConfiguration (
        /*[out,retval]*/ struct IScriptConfiguration2 * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Settings (
        /*[out,retval]*/ struct IZoomTextSettings6 * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Speech (
        /*[out,retval]*/ struct ISpeech2 * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Version (
        /*[out,retval]*/ BSTR * pVersion ) = 0;
      virtual HRESULT __stdcall get_ZTCommand (
        /*[out,retval]*/ struct IZTCommand * * ppObj ) = 0;
      virtual HRESULT __stdcall CreateObjectFromAhoiId (
        /*[in]*/ BSTR bstrObjName,
        /*[in]*/ struct tagAHOIOBJECTID AhoiId,
        /*[out,retval]*/ IUnknown * * ppObj ) = 0;
      virtual HRESULT __stdcall CreateSpeechEventObject (
        /*[in]*/ BSTR bstrClient,
        /*[in]*/ BSTR bstrText,
        /*[in]*/ unsigned long dwFlags,
        /*[out,retval]*/ IUnknown * * ppObj ) = 0;
      virtual HRESULT __stdcall get_ScriptManager (
        /*[out,retval]*/ struct IScriptManager * * ppObj ) = 0;
};

struct __declspec(uuid("6820972a-1abd-4bcf-924a-60053fac4a8d"))
ITextSearchOption : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Type (
        /*[out,retval]*/ BSTR * pType ) = 0;
      virtual HRESULT __stdcall put_Type (
        /*[in]*/ BSTR pType ) = 0;
      virtual HRESULT __stdcall get_Area (
        /*[out,retval]*/ BSTR * pArea ) = 0;
      virtual HRESULT __stdcall put_Area (
        /*[in]*/ BSTR pArea ) = 0;
      virtual HRESULT __stdcall get_StartFrom (
        /*[out,retval]*/ BSTR * pStartFrom ) = 0;
      virtual HRESULT __stdcall put_StartFrom (
        /*[in]*/ BSTR pStartFrom ) = 0;
      virtual HRESULT __stdcall get_WholeWords (
        /*[out,retval]*/ VARIANT_BOOL * pWholeWords ) = 0;
      virtual HRESULT __stdcall put_WholeWords (
        /*[in]*/ VARIANT_BOOL pWholeWords ) = 0;
      virtual HRESULT __stdcall get_CaseSensitive (
        /*[out,retval]*/ VARIANT_BOOL * pCase ) = 0;
      virtual HRESULT __stdcall put_CaseSensitive (
        /*[in]*/ VARIANT_BOOL pCase ) = 0;
      virtual HRESULT __stdcall Reset ( ) = 0;
};

struct __declspec(uuid("30ef42de-166e-4bd4-b864-0bec8dc143f3"))
IApplicationObject : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Active (
        /*[out,retval]*/ VARIANT_BOOL * pActive ) = 0;
      virtual HRESULT __stdcall get_Module (
        /*[out,retval]*/ BSTR * Name ) = 0;
      virtual HRESULT __stdcall get_FriendlyName (
        /*[out,retval]*/ BSTR * Name ) = 0;
      virtual HRESULT __stdcall get_ProcessID (
        /*[out,retval]*/ long * pProcID ) = 0;
      virtual HRESULT __stdcall get_WindowRoot (
        /*[out,retval]*/ IDispatch * * ppWindow ) = 0;
      virtual HRESULT __stdcall Activate ( ) = 0;
};

struct __declspec(uuid("a3b6c1b2-5b5a-48d3-889b-f77b4087e860"))
IFontObject : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_FontName (
        /*[out,retval]*/ BSTR * pName ) = 0;
      virtual HRESULT __stdcall get_FontSize (
        /*[out,retval]*/ long * pSize ) = 0;
      virtual HRESULT __stdcall get_TextColor (
        /*[out,retval]*/ long * pColor ) = 0;
      virtual HRESULT __stdcall get_BackgroundColor (
        /*[out,retval]*/ long * pColor ) = 0;
      virtual HRESULT __stdcall get_Bold (
        /*[out,retval]*/ VARIANT_BOOL * pBold ) = 0;
      virtual HRESULT __stdcall get_Italic (
        /*[out,retval]*/ VARIANT_BOOL * pItalic ) = 0;
      virtual HRESULT __stdcall get_Underline (
        /*[out,retval]*/ VARIANT_BOOL * pUnderline ) = 0;
      virtual HRESULT __stdcall get_Strikeout (
        /*[out,retval]*/ VARIANT_BOOL * pStrikeout ) = 0;
};

struct __declspec(uuid("7dc44c70-d1e4-4477-9e4a-ccdb38c862f7"))
ITextObject : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Type (
        /*[out,retval]*/ BSTR * pType ) = 0;
      virtual HRESULT __stdcall put_Type (
        /*[in]*/ BSTR pType ) = 0;
      virtual HRESULT __stdcall get_Next (
        /*[out,retval]*/ struct ITextObject * * ppTextObject ) = 0;
      virtual HRESULT __stdcall get_Previous (
        /*[out,retval]*/ struct ITextObject * * ppTextObject ) = 0;
      virtual HRESULT __stdcall get_Text (
        /*[out,retval]*/ BSTR * pText ) = 0;
      virtual HRESULT __stdcall get_Location (
        /*[out,retval]*/ struct IRectangle * * pRectangle ) = 0;
      virtual HRESULT __stdcall get_Application (
        /*[out,retval]*/ struct IApplicationObject * * pApplication ) = 0;
      virtual HRESULT __stdcall get_Window (
        /*[out,retval]*/ IDispatch * * pWindow ) = 0;
      virtual HRESULT __stdcall get_Font (
        /*[out,retval]*/ struct IFontObject * * pFont ) = 0;
};

struct __declspec(uuid("a04731f3-3f79-4afd-8658-1673d5e56ece"))
ITextCursor : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Location (
        /*[out,retval]*/ struct IRectangle * * pRectangle ) = 0;
      virtual HRESULT __stdcall get_Text (
        /*[out,retval]*/ struct ITextObject * * ppTextObject ) = 0;
      virtual HRESULT __stdcall get_Application (
        /*[out,retval]*/ struct IApplicationObject * * pApplication ) = 0;
      virtual HRESULT __stdcall get_Window (
        /*[out,retval]*/ IDispatch * * pWindow ) = 0;
};

struct __declspec(uuid("0d7614b7-c695-4527-9b99-aca804aacb5e"))
ITextSearch : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Options (
        /*[out,retval]*/ struct ITextSearchOption * * ppOption ) = 0;
      virtual HRESULT __stdcall AtPoint (
        /*[in]*/ struct IPoint * pPoint,
        /*[out,retval]*/ struct ITextObject * * ppTextObj ) = 0;
      virtual HRESULT __stdcall CollectionInRect (
        /*[in]*/ struct IRectangle * pRect,
        /*[out,retval]*/ struct IObjectCollection * * ppObjectCollection ) = 0;
      virtual HRESULT __stdcall InRect (
        /*[in]*/ struct IRectangle * pRect,
        /*[out,retval]*/ struct ITextObject * * ppTextObject ) = 0;
      virtual HRESULT __stdcall TextCursor (
        /*[out,retval]*/ struct ITextCursor * * ppTextCursor ) = 0;
      virtual HRESULT __stdcall FirstVisible (
        /*[out,retval]*/ struct ITextObject * * ppTextObject ) = 0;
      virtual HRESULT __stdcall FindTextObject (
        /*[in]*/ BSTR bstr,
        /*[out,retval]*/ struct IObjectCollection * * ppObjectCollection ) = 0;
};

struct __declspec(uuid("a4e4b0f5-5321-4e2c-9526-a5b33e890d17"))
IApplicationSearch : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Active (
        /*[out,retval]*/ struct IApplicationObject * * ppApp ) = 0;
      virtual HRESULT __stdcall Applications (
        /*[out,retval]*/ struct IObjectCollection * * ppAppColl ) = 0;
      virtual HRESULT __stdcall ByModuleName (
        /*[in]*/ BSTR bstr,
        /*[out,retval]*/ struct IObjectCollection * * ppAppColl ) = 0;
      virtual HRESULT __stdcall AtPoint (
        /*[in]*/ struct IPoint * pPoint,
        /*[out,retval]*/ struct IApplicationObject * * ppApp ) = 0;
};

struct __declspec(uuid("67c6cf6a-afda-44be-bcf9-c70e28c9ee91"))
IWindowSearch : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Active (
        /*[out,retval]*/ IDispatch * * ppWindow ) = 0;
      virtual HRESULT __stdcall AtPoint (
        /*[in]*/ struct IPoint * pPoint,
        /*[out,retval]*/ IDispatch * * ppWindow ) = 0;
      virtual HRESULT __stdcall FindWindowObject (
        /*[in]*/ BSTR bstrClassName,
        /*[in]*/ BSTR bstrWindowTitle,
        /*[out,retval]*/ struct IObjectCollection * * ppWindow ) = 0;
};

struct __declspec(uuid("5a1f732f-6c70-4b4e-bdf8-b0ecf9500134"))
IWindowObject : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall Activate ( ) = 0;
      virtual HRESULT __stdcall get_Active (
        /*[out,retval]*/ VARIANT_BOOL * pActive ) = 0;
      virtual HRESULT __stdcall get_Application (
        /*[out,retval]*/ struct IApplicationObject * * ppApplication ) = 0;
      virtual HRESULT __stdcall get_ClassName (
        /*[out,retval]*/ BSTR * pClassName ) = 0;
      virtual HRESULT __stdcall get_Enabled (
        /*[out,retval]*/ VARIANT_BOOL * pVisible ) = 0;
      virtual HRESULT __stdcall get_FirstChild (
        /*[out,retval]*/ IDispatch * * ppWindow ) = 0;
      virtual HRESULT __stdcall get_Focus (
        /*[out,retval]*/ VARIANT_BOOL * pActive ) = 0;
      virtual HRESULT __stdcall get_Hotkey (
        /*[out,retval]*/ BSTR * pHotkey ) = 0;
      virtual HRESULT __stdcall get_HWnd (
        /*[out,retval]*/ long * pHWnd ) = 0;
      virtual HRESULT __stdcall get_LastChild (
        /*[out,retval]*/ IDispatch * * ppWindow ) = 0;
      virtual HRESULT __stdcall get_Location (
        /*[out,retval]*/ struct IRectangle * * pRectangle ) = 0;
      virtual HRESULT __stdcall get_NextSibling (
        /*[out,retval]*/ IDispatch * * ppWindow ) = 0;
      virtual HRESULT __stdcall get_Parent (
        /*[out,retval]*/ IDispatch * * ppWindow ) = 0;
      virtual HRESULT __stdcall get_PreviousSibling (
        /*[out,retval]*/ IDispatch * * ppWindow ) = 0;
      virtual HRESULT __stdcall get_Text (
        /*[out,retval]*/ BSTR * pText ) = 0;
      virtual HRESULT __stdcall get_Title (
        /*[out,retval]*/ BSTR * pTitle ) = 0;
      virtual HRESULT __stdcall get_Type (
        /*[out,retval]*/ BSTR * pType ) = 0;
      virtual HRESULT __stdcall get_Visible (
        /*[out,retval]*/ VARIANT_BOOL * pVisible ) = 0;
};

struct __declspec(uuid("477f6a4d-ad3d-49be-a990-c56dd52614fb"))
ICheckBox : IWindowObject
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_CheckState (
        /*[out,retval]*/ BSTR * pState ) = 0;
};

struct __declspec(uuid("ae0e849f-ed2b-494d-9a02-9db2f021dda5"))
IItemObject : IWindowObject
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Selected (
        /*[out,retval]*/ VARIANT_BOOL * pSelected ) = 0;
};

struct __declspec(uuid("c644815f-2157-4854-861d-e433da8da5b0"))
IComboBox : IWindowObject
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_SelectedItem (
        /*[out,retval]*/ struct IItemObject * * pListItem ) = 0;
      virtual HRESULT __stdcall get_NumberOfItems (
        /*[out,retval]*/ long * pNumber ) = 0;
      virtual HRESULT __stdcall get_ReadOnly (
        /*[out,retval]*/ VARIANT_BOOL * pReadOnly ) = 0;
      virtual HRESULT __stdcall get_Open (
        /*[out,retval]*/ VARIANT_BOOL * pOpen ) = 0;
};

struct __declspec(uuid("37e5004f-2bbd-4800-bd87-b8883b6a2a83"))
IEditBox : IWindowObject
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_ReadOnly (
        /*[out,retval]*/ VARIANT_BOOL * pReadOnly ) = 0;
      virtual HRESULT __stdcall get_MultiLine (
        /*[out,retval]*/ VARIANT_BOOL * pMultiLine ) = 0;
      virtual HRESULT __stdcall get_RichText (
        /*[out,retval]*/ VARIANT_BOOL * pRichText ) = 0;
      virtual HRESULT __stdcall get_Password (
        /*[out,retval]*/ VARIANT_BOOL * pPassword ) = 0;
};

struct __declspec(uuid("fb9e3e9b-374d-4e3f-9203-7c3d8f848f41"))
ILink : IWindowObject
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Visited (
        /*[out,retval]*/ VARIANT_BOOL * pVisited ) = 0;
      virtual HRESULT __stdcall get_URL (
        /*[out,retval]*/ BSTR * pURL ) = 0;
};

struct __declspec(uuid("32a532d8-5f54-4e5a-876a-737a87c8cee1"))
IListView : IWindowObject
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_SelectedItem (
        /*[out,retval]*/ struct IItemObject * * pListItem ) = 0;
      virtual HRESULT __stdcall get_NumberOfItems (
        /*[out,retval]*/ long * pNumber ) = 0;
      virtual HRESULT __stdcall get_NumberOfColumns (
        /*[out,retval]*/ long * pNumber ) = 0;
      virtual HRESULT __stdcall get_ViewType (
        /*[out,retval]*/ BSTR * pViewType ) = 0;
};

struct __declspec(uuid("836a99ad-bcbe-4534-a8a2-73addfcc7571"))
IMenuItem : IWindowObject
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_ShortCut (
        /*[out,retval]*/ BSTR * pShortCut ) = 0;
      virtual HRESULT __stdcall get_Selected (
        /*[out,retval]*/ VARIANT_BOOL * pSelected ) = 0;
      virtual HRESULT __stdcall get_Checked (
        /*[out,retval]*/ VARIANT_BOOL * pChecked ) = 0;
      virtual HRESULT __stdcall get_HasSubmenu (
        /*[out,retval]*/ VARIANT_BOOL * pHasSubmenu ) = 0;
};

struct __declspec(uuid("0680f1b0-823e-4953-a9ff-f52c407a59fd"))
IRadioButton : IWindowObject
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Checked (
        /*[out,retval]*/ VARIANT_BOOL * pChecked ) = 0;
};

struct __declspec(uuid("3656a1fc-dfea-4acf-9c78-675be5ea272d"))
IScrollBar : IWindowObject
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Direction (
        /*[out,retval]*/ BSTR * pDirection ) = 0;
      virtual HRESULT __stdcall get_Percent (
        /*[out,retval]*/ long * pPercent ) = 0;
};

struct __declspec(uuid("68dd54e0-183d-41ae-bf86-4da434814302"))
ITrackBar : IWindowObject
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Position (
        /*[out,retval]*/ long * pPosition ) = 0;
};

struct __declspec(uuid("4f521c31-ee39-4cf7-a200-e9850a9c070c"))
ITreeView : IWindowObject
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_SelectedItem (
        /*[out,retval]*/ struct IItemObject * * pListItem ) = 0;
      virtual HRESULT __stdcall get_SelectedLevel (
        /*[out,retval]*/ long * pSelectedLevel ) = 0;
};

struct __declspec(uuid("8511473e-8fde-4327-bfad-ec59f77fcb3f"))
ISpeechEventObject : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Client (
        /*[out,retval]*/ BSTR * pbstrClient ) = 0;
      virtual HRESULT __stdcall put_Client (
        /*[in]*/ BSTR pbstrClient ) = 0;
      virtual HRESULT __stdcall get_Text (
        /*[out,retval]*/ BSTR * pbstrText ) = 0;
      virtual HRESULT __stdcall put_Text (
        /*[in]*/ BSTR pbstrText ) = 0;
      virtual HRESULT __stdcall get_Voice (
        /*[out,retval]*/ struct IVoice * * pVoice ) = 0;
      virtual HRESULT __stdcall get_Flags (
        /*[out,retval]*/ unsigned long * pdwFlags ) = 0;
      virtual HRESULT __stdcall put_Flags (
        /*[in]*/ unsigned long pdwFlags ) = 0;
};

struct __declspec(uuid("c27bb1e7-6142-4a9d-8db1-8571b09e4363"))
IEnvironment : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_OperatingSystemVersion (
        /*[out,retval]*/ long * pOpSysVer ) = 0;
};

struct __declspec(uuid("d226d606-a89c-4277-a396-ab57f9d2c1bd"))
IWindowObjectOption : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_NavigateToNotVisible (
        /*[out,retval]*/ VARIANT_BOOL * pBool ) = 0;
      virtual HRESULT __stdcall put_NavigateToNotVisible (
        /*[in]*/ VARIANT_BOOL pBool ) = 0;
      virtual HRESULT __stdcall get_NavigateToUnnamed (
        /*[out,retval]*/ VARIANT_BOOL * pBool ) = 0;
      virtual HRESULT __stdcall put_NavigateToUnnamed (
        /*[in]*/ VARIANT_BOOL pBool ) = 0;
      virtual HRESULT __stdcall Reset ( ) = 0;
};

struct __declspec(uuid("f71a5b7c-bb03-45ac-9703-ddfff9a94807"))
IWindowObject2 : IWindowObject
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_ControlID (
        /*[out,retval]*/ BSTR * pId ) = 0;
      virtual HRESULT __stdcall MakeVisible ( ) = 0;
      virtual HRESULT __stdcall get_Options (
        /*[out,retval]*/ struct IWindowObjectOption * * ppOptions ) = 0;
      virtual HRESULT __stdcall SetFocus ( ) = 0;
      virtual HRESULT __stdcall get_TopMost (
        /*[out,retval]*/ VARIANT_BOOL * pTopMost ) = 0;
};

struct __declspec(uuid("19e19ae5-d44b-4c67-ba8e-37bdf971bf90"))
IHeaderControl : IWindowObject2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Level (
        /*[out,retval]*/ long * pLevel ) = 0;
};

struct __declspec(uuid("4a9140b5-7c86-4a9c-8ea9-5c84755841e1"))
ICheckBox2 : IWindowObject2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_CheckState (
        /*[out,retval]*/ BSTR * pState ) = 0;
};

struct __declspec(uuid("97787e6b-a70d-4a65-a74a-10a33c031b61"))
IItemObject2 : IWindowObject2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Selected (
        /*[out,retval]*/ VARIANT_BOOL * pSelected ) = 0;
};

struct __declspec(uuid("a1ca3f99-86f1-4b78-9267-046ad32782c7"))
IComboBox2 : IWindowObject2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_SelectedItem (
        /*[out,retval]*/ struct IItemObject2 * * pListItem ) = 0;
      virtual HRESULT __stdcall get_NumberOfItems (
        /*[out,retval]*/ long * pNumber ) = 0;
      virtual HRESULT __stdcall get_ReadOnly (
        /*[out,retval]*/ VARIANT_BOOL * pReadOnly ) = 0;
      virtual HRESULT __stdcall get_Open (
        /*[out,retval]*/ VARIANT_BOOL * pOpen ) = 0;
};

struct __declspec(uuid("ef4fe0d9-8e73-4e99-9d98-4438a4c023b1"))
IEditBox2 : IWindowObject2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_ReadOnly (
        /*[out,retval]*/ VARIANT_BOOL * pReadOnly ) = 0;
      virtual HRESULT __stdcall get_MultiLine (
        /*[out,retval]*/ VARIANT_BOOL * pMultiLine ) = 0;
      virtual HRESULT __stdcall get_RichText (
        /*[out,retval]*/ VARIANT_BOOL * pRichText ) = 0;
      virtual HRESULT __stdcall get_Password (
        /*[out,retval]*/ VARIANT_BOOL * pPassword ) = 0;
};

struct __declspec(uuid("f2a6d33c-f60b-4e89-98f2-c00b4413befe"))
ILink2 : IWindowObject2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Visited (
        /*[out,retval]*/ VARIANT_BOOL * pVisited ) = 0;
      virtual HRESULT __stdcall get_URL (
        /*[out,retval]*/ BSTR * pURL ) = 0;
};

struct __declspec(uuid("ba4119f3-7735-4c7f-980d-f92f20b103d3"))
IListView2 : IWindowObject2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_SelectedItem (
        /*[out,retval]*/ struct IItemObject2 * * pListItem ) = 0;
      virtual HRESULT __stdcall get_NumberOfItems (
        /*[out,retval]*/ long * pNumber ) = 0;
      virtual HRESULT __stdcall get_NumberOfColumns (
        /*[out,retval]*/ long * pNumber ) = 0;
      virtual HRESULT __stdcall get_ViewType (
        /*[out,retval]*/ BSTR * pViewType ) = 0;
};

struct __declspec(uuid("e11c2304-a3b0-4f17-8c36-1970d709156a"))
IMenuItem2 : IWindowObject2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_ShortCut (
        /*[out,retval]*/ BSTR * pShortCut ) = 0;
      virtual HRESULT __stdcall get_Selected (
        /*[out,retval]*/ VARIANT_BOOL * pSelected ) = 0;
      virtual HRESULT __stdcall get_Checked (
        /*[out,retval]*/ VARIANT_BOOL * pChecked ) = 0;
      virtual HRESULT __stdcall get_HasSubmenu (
        /*[out,retval]*/ VARIANT_BOOL * pHasSubmenu ) = 0;
};

struct __declspec(uuid("e81982ec-7a3a-4d15-b126-75ccc520bd81"))
IObjectStore : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall Add (
        /*[in]*/ BSTR pName,
        /*[in]*/ VARIANT varValue ) = 0;
      virtual HRESULT __stdcall Delete (
        /*[in]*/ BSTR bstrName ) = 0;
      virtual HRESULT __stdcall Get (
        /*[in]*/ BSTR pName,
        /*[out,retval]*/ VARIANT * pvarValue ) = 0;
};

struct __declspec(uuid("93cefb5d-e673-434a-af70-93d4a6fee9d8"))
IRadioButton2 : IWindowObject2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Checked (
        /*[out,retval]*/ VARIANT_BOOL * pChecked ) = 0;
};

struct __declspec(uuid("179608af-19d4-4d94-83fc-315814b0c0a9"))
IScrollBar2 : IWindowObject2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Direction (
        /*[out,retval]*/ BSTR * pDirection ) = 0;
      virtual HRESULT __stdcall get_Percent (
        /*[out,retval]*/ long * pPercent ) = 0;
};

struct __declspec(uuid("2f6b91fe-8dad-40c6-8151-d3533585badd"))
ITrackBar2 : IWindowObject2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Position (
        /*[out,retval]*/ long * pPosition ) = 0;
};

struct __declspec(uuid("c8d6adcf-e992-45ef-bb3f-a9572dc85752"))
ITreeView2 : IWindowObject2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_SelectedItem (
        /*[out,retval]*/ struct IItemObject2 * * pListItem ) = 0;
      virtual HRESULT __stdcall get_SelectedLevel (
        /*[out,retval]*/ long * pSelectedLevel ) = 0;
};

struct __declspec(uuid("6f4c7c49-96a6-4c87-926a-79083a19d534"))
IWindowSearchOption : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_PreferAHOI (
        /*[out,retval]*/ VARIANT_BOOL * pBool ) = 0;
      virtual HRESULT __stdcall put_PreferAHOI (
        /*[in]*/ VARIANT_BOOL pBool ) = 0;
      virtual HRESULT __stdcall get_PreferZSM (
        /*[out,retval]*/ VARIANT_BOOL * pBool ) = 0;
      virtual HRESULT __stdcall put_PreferZSM (
        /*[in]*/ VARIANT_BOOL pBool ) = 0;
      virtual HRESULT __stdcall get_FindOnly (
        /*[out,retval]*/ BSTR * pType ) = 0;
      virtual HRESULT __stdcall put_FindOnly (
        /*[in]*/ BSTR pType ) = 0;
      virtual HRESULT __stdcall Reset ( ) = 0;
};

struct __declspec(uuid("ffc01288-cb56-4c56-b082-eeddd8c0e144"))
IWindowSearch2 : IWindowSearch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Options (
        /*[out,retval]*/ struct IWindowSearchOption * * ppOptions ) = 0;
};

struct __declspec(uuid("87908e23-dcfb-4a32-82c6-5e54c4870d4d"))
IWebPage : IWindowObject2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_URL (
        /*[out,retval]*/ BSTR * pStr ) = 0;
};

struct __declspec(uuid("c954470b-98e8-4214-a011-b556dbdf26a6"))
IZoomText2 : IZoomText
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Environment (
        /*[out,retval]*/ struct IEnvironment * * ppObj ) = 0;
      virtual HRESULT __stdcall get_ObjectStore (
        /*[out,retval]*/ struct IObjectStore * * ppObj ) = 0;
};

struct __declspec(uuid("22e2cc6c-e8e3-4209-bbfd-d4cc65fa613a"))
ICCTV2 : ICCTV
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_SharedFileName (
        /*[out,retval]*/ BSTR * pSharedFileName ) = 0;
      virtual HRESULT __stdcall get_UpdateEventName (
        /*[out,retval]*/ BSTR * pEventName ) = 0;
};

struct __declspec(uuid("4461cd62-37bc-409e-96cd-7f66eab86cfc"))
ICCTV3 : ICCTV2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall SetStreamStretch (
        /*[in]*/ long cx,
        /*[in]*/ long cy ) = 0;
      virtual HRESULT __stdcall SetStreamSourceArea (
        /*[in]*/ long left,
        /*[in]*/ long top,
        /*[in]*/ long right,
        /*[in]*/ long bottom ) = 0;
};

struct __declspec(uuid("ac9927f4-c123-4730-b91c-266aaa93d22a"))
IMagnification4 : IMagnification3
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_CCTV2 (
        /*[out,retval]*/ struct ICCTV2 * * ppCCTV ) = 0;
      virtual HRESULT __stdcall get_CCTV3 (
        /*[out,retval]*/ struct ICCTV3 * * ppCCTV ) = 0;
};

struct __declspec(uuid("ab6dcbfd-6aa8-4f70-b3a6-19e9770019b9"))
IZoomText3 : IZoomText2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Magnification4 (
        /*[out,retval]*/ struct IMagnification4 * * ppObj ) = 0;
};

struct __declspec(uuid("46b53ce7-45b6-4ef9-98fd-58de15bd2b33"))
ICCTV4 : ICCTV3
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall SetBorderColor (
        /*[in]*/ long dwABGRColor ) = 0;
      virtual HRESULT __stdcall SetBorderThickness (
        /*[in]*/ long dwThickness ) = 0;
};

struct __declspec(uuid("1cfc89ff-5c33-4db7-aaaf-4b4bf7665d2a"))
IMagnification5 : IMagnification4
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_CCTV4 (
        /*[out,retval]*/ struct ICCTV4 * * ppCCTV ) = 0;
};

struct __declspec(uuid("c65cd7e2-45a5-46f4-9165-80c90bdd9e0b"))
IZoomText4 : IZoomText3
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Magnification5 (
        /*[out,retval]*/ struct IMagnification5 * * ppObj ) = 0;
};

struct __declspec(uuid("79acb813-a53b-4c99-a57f-129b546eb2c3"))
IMagnification6 : IMagnification5
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_CaretEnhancements1 (
        /*[out,retval]*/ struct ICaretEnhancements * * ppCaretEnhancements ) = 0;
      virtual HRESULT __stdcall get_CaretEnhancements2 (
        /*[out,retval]*/ struct ICaretEnhancements2 * * ppCaretEnhancements ) = 0;
      virtual HRESULT __stdcall get_CaretEnhancements3 (
        /*[out,retval]*/ struct ICaretEnhancements3 * * ppCaretEnhancements ) = 0;
      virtual HRESULT __stdcall get_ColorEnhancements1 (
        /*[out,retval]*/ struct IColorEnhancements * * ppColorEnhancements ) = 0;
      virtual HRESULT __stdcall get_ColorEnhancements2 (
        /*[out,retval]*/ struct IColorEnhancements2 * * ppColorEnhancements ) = 0;
      virtual HRESULT __stdcall get_FocusEnhancements1 (
        /*[out,retval]*/ struct IFocusEnhancements * * ppFocusEnhancements ) = 0;
      virtual HRESULT __stdcall get_FocusEnhancements2 (
        /*[out,retval]*/ struct IFocusEnhancements2 * * ppFocusEnhancements ) = 0;
      virtual HRESULT __stdcall get_FocusEnhancements3 (
        /*[out,retval]*/ struct IFocusEnhancements3 * * ppFocusEnhancements ) = 0;
      virtual HRESULT __stdcall get_PointerEnhancements1 (
        /*[out,retval]*/ struct IPointerEnhancements * * ppPointerEnhancements ) = 0;
      virtual HRESULT __stdcall get_PointerEnhancements2 (
        /*[out,retval]*/ struct IPointerEnhancements2 * * ppPointerEnhancements ) = 0;
};

struct __declspec(uuid("e2edafe4-9f12-4902-9086-5f600516c5da"))
IZoomText5 : IZoomText4
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Magnification6 (
        /*[out,retval]*/ struct IMagnification6 * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Reader1 (
        /*[out,retval]*/ struct IReader * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Reader2 (
        /*[out,retval]*/ struct IReader2 * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Reader3 (
        /*[out,retval]*/ struct IReader3 * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Reader4 (
        /*[out,retval]*/ struct IReader4 * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Settings1 (
        /*[out,retval]*/ struct IZoomTextSettings * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Settings2 (
        /*[out,retval]*/ struct IZoomTextSettings2 * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Settings3 (
        /*[out,retval]*/ struct IZoomTextSettings3 * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Settings4 (
        /*[out,retval]*/ struct IZoomTextSettings4 * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Settings5 (
        /*[out,retval]*/ struct IZoomTextSettings5 * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Settings6 (
        /*[out,retval]*/ struct IZoomTextSettings6 * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Hotkeys1 (
        /*[out,retval]*/ struct IHotkeys * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Hotkeys2 (
        /*[out,retval]*/ struct IHotkeys2 * * ppObj ) = 0;
};

struct __declspec(uuid("a595d144-d88d-4724-8a3a-5c937f9f4f29"))
ICCTV5 : ICCTV4
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_MultipleMonitorsSupported (
        /*[out,retval]*/ VARIANT_BOOL * pbMultipleMonitorsSupported ) = 0;
};

struct __declspec(uuid("69c6dc1f-d8a0-434d-82ea-f8e48a6da817"))
IMagnification7 : IMagnification6
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_CCTV5 (
        /*[out,retval]*/ struct ICCTV5 * * ppCCTV ) = 0;
};

struct __declspec(uuid("4d2bc8ae-fe6d-41c5-80a1-922f5eb44f59"))
IZoomText6 : IZoomText5
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Magnification7 (
        /*[out,retval]*/ struct IMagnification7 * * ppObj ) = 0;
      virtual HRESULT __stdcall get_WindowHandle (
        /*[out,retval]*/ long * pWnd ) = 0;
};

struct __declspec(uuid("2802ebf9-069f-4245-8e35-77ba2c58f462"))
IControl : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_FocusEnhancement (
        /*[out,retval]*/ BSTR * pControlledBy ) = 0;
      virtual HRESULT __stdcall put_FocusEnhancement (
        /*[in]*/ BSTR pControlledBy ) = 0;
      virtual HRESULT __stdcall get_CaretEnhancement (
        /*[out,retval]*/ BSTR * pControlledBy ) = 0;
      virtual HRESULT __stdcall put_CaretEnhancement (
        /*[in]*/ BSTR pControlledBy ) = 0;
      virtual HRESULT __stdcall get_Tracking (
        /*[out,retval]*/ BSTR * pControlledBy ) = 0;
      virtual HRESULT __stdcall put_Tracking (
        /*[in]*/ BSTR pControlledBy ) = 0;
      virtual HRESULT __stdcall get_ProgramEcho (
        /*[out,retval]*/ BSTR * pControlledBy ) = 0;
      virtual HRESULT __stdcall put_ProgramEcho (
        /*[in]*/ BSTR pControlledBy ) = 0;
      virtual HRESULT __stdcall get_TypingEcho (
        /*[out,retval]*/ BSTR * pControlledBy ) = 0;
      virtual HRESULT __stdcall put_TypingEcho (
        /*[in]*/ BSTR pControlledBy ) = 0;
      virtual HRESULT __stdcall get_MouseEcho (
        /*[out,retval]*/ BSTR * pControlledBy ) = 0;
      virtual HRESULT __stdcall put_MouseEcho (
        /*[in]*/ BSTR pControlledBy ) = 0;
};

struct __declspec(uuid("a9224504-4499-45ff-a8c9-a327b328fdd5"))
IControlAppProperties : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_FocusEnhancement (
        /*[out,retval]*/ BSTR * pControlledBy ) = 0;
      virtual HRESULT __stdcall put_FocusEnhancement (
        /*[in]*/ BSTR pControlledBy ) = 0;
      virtual HRESULT __stdcall get_CaretEnhancement (
        /*[out,retval]*/ BSTR * pControlledBy ) = 0;
      virtual HRESULT __stdcall put_CaretEnhancement (
        /*[in]*/ BSTR pControlledBy ) = 0;
      virtual HRESULT __stdcall get_Tracking (
        /*[out,retval]*/ BSTR * pControlledBy ) = 0;
      virtual HRESULT __stdcall put_Tracking (
        /*[in]*/ BSTR pControlledBy ) = 0;
      virtual HRESULT __stdcall get_ProgramEcho (
        /*[out,retval]*/ BSTR * pControlledBy ) = 0;
      virtual HRESULT __stdcall put_ProgramEcho (
        /*[in]*/ BSTR pControlledBy ) = 0;
      virtual HRESULT __stdcall get_TypingEcho (
        /*[out,retval]*/ BSTR * pControlledBy ) = 0;
      virtual HRESULT __stdcall put_TypingEcho (
        /*[in]*/ BSTR pControlledBy ) = 0;
      virtual HRESULT __stdcall get_MouseEcho (
        /*[out,retval]*/ BSTR * pControlledBy ) = 0;
      virtual HRESULT __stdcall put_MouseEcho (
        /*[in]*/ BSTR pControlledBy ) = 0;
};

struct __declspec(uuid("93eb8471-756d-46fc-9891-ba8d893a1c0d"))
IControlApp : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall Application (
        /*[in]*/ BSTR pApplicationModule,
        /*[out,retval]*/ struct IControlAppProperties * * ppControlAppProperties ) = 0;
};

struct __declspec(uuid("3e3aee84-0ed6-44a9-a481-fc7770026f02"))
IMagnification8 : IMagnification7
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_FocusEnhancements4 (
        /*[out,retval]*/ struct IFocusEnhancements4 * * ppFocusEnhancements ) = 0;
      virtual HRESULT __stdcall get_CaretEnhancements4 (
        /*[out,retval]*/ struct ICaretEnhancements4 * * ppCaretEnhancements ) = 0;
};

struct __declspec(uuid("1cd1670d-bdd5-4c8f-a918-00e3d540e1bd"))
IZoomText7 : IZoomText6
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Control (
        /*[out,retval]*/ struct IControl * * ppObj ) = 0;
      virtual HRESULT __stdcall get_ControlApp (
        /*[out,retval]*/ struct IControlApp * * ppObj ) = 0;
      virtual HRESULT __stdcall get_Magnification8 (
        /*[out,retval]*/ struct IMagnification8 * * ppObj ) = 0;
      virtual HRESULT __stdcall ApplicationChanged (
        /*[in]*/ BSTR bstrAppName ) = 0;
};

struct __declspec(uuid("92231697-6ead-408d-9395-6a688b885586"))
ISpeaker2 : ISpeaker
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_OutputToFileSupported (
        /*[out,retval]*/ VARIANT_BOOL * pbSupported ) = 0;
      virtual HRESULT __stdcall get_SynthesizerType (
        /*[out,retval]*/ unsigned long * pdwEngineType ) = 0;
      virtual HRESULT __stdcall get_RateStep (
        /*[out,retval]*/ long * pdwRateStep ) = 0;
};

struct __declspec(uuid("d38f0d27-fc81-4836-8886-0ec9bdb417d3"))
IVoice2 : IVoice
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_OutputToFileSupported (
        /*[out,retval]*/ VARIANT_BOOL * pbSupported ) = 0;
      virtual HRESULT __stdcall get_SynthesizerType (
        /*[out,retval]*/ unsigned long * pdwEngineType ) = 0;
};

struct __declspec(uuid("b0b9cb1d-3369-482d-8c2e-3cb254dbff0c"))
ISpeech3 : ISpeech2
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_CurrentVoice3 (
        /*[out,retval]*/ struct IVoice2 * * ppVoice ) = 0;
      virtual HRESULT __stdcall put_CurrentVoice3 (
        /*[in]*/ struct IVoice2 * ppVoice ) = 0;
      virtual HRESULT __stdcall FindVoice3 (
        /*[in]*/ BSTR bstrProductName,
        /*[in]*/ BSTR bstrVoiceName,
        /*[out,retval]*/ struct IVoice2 * * ppVoice ) = 0;
      virtual HRESULT __stdcall CreateSpeaker3 (
        /*[in]*/ struct IVoice2 * pVoice,
        /*[out,retval]*/ struct ISpeaker2 * * ppSpeaker ) = 0;
      virtual HRESULT __stdcall DeleteSpeaker3 (
        /*[in]*/ struct ISpeaker2 * pSpeaker ) = 0;
      virtual HRESULT __stdcall GetEngineDisplayName (
        /*[in]*/ BSTR bstrProductName,
        /*[in]*/ unsigned long idLang,
        /*[out,retval]*/ BSTR * ppDisplayName ) = 0;
};

struct __declspec(uuid("796718e4-f2b9-4d7d-8970-ac1a26d816f7"))
IZoomText8 : IZoomText7
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Speech3 (
        /*[out,retval]*/ struct ISpeech3 * * ppObj ) = 0;
};

struct __declspec(uuid("97ea7ed1-3acc-4cba-8df9-4ecbe9558271"))
IFontEnhancements2 : IFontEnhancements
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_SmoothingType (
        /*[out,retval]*/ BSTR * pSmoothingType ) = 0;
      virtual HRESULT __stdcall put_SmoothingType (
        /*[in]*/ BSTR pSmoothingType ) = 0;
};

struct __declspec(uuid("d1d89c6e-4cdb-4b66-af63-57ca40555407"))
IMagnification9 : IMagnification8
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_FontEnhancements2 (
        /*[out,retval]*/ struct IFontEnhancements2 * * ppFontEnhancements ) = 0;
};

struct __declspec(uuid("d629bc1e-21e2-4509-9347-e7d3fadf8470"))
IZoomText9 : IZoomText8
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Magnification9 (
        /*[out,retval]*/ struct IMagnification9 * * ppObj ) = 0;
};

struct __declspec(uuid("9a67b4ec-2046-4227-80ca-44739b3b5256"))
ITetheredViewSettings : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Enabled (
        /*[out,retval]*/ VARIANT_BOOL * value ) = 0;
      virtual HRESULT __stdcall put_Enabled (
        /*[in]*/ VARIANT_BOOL value ) = 0;
};

struct __declspec(uuid("915c2a11-8a83-4608-9aef-aa9afb47b8e0"))
ITetheredViewScenario : IDispatch
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Name (
        /*[out,retval]*/ BSTR * Name ) = 0;
      virtual HRESULT __stdcall put_Name (
        /*[in]*/ BSTR Name ) = 0;
      virtual HRESULT __stdcall put_MinimalSourceWidth (
        /*[in]*/ long _arg1 ) = 0;
      virtual HRESULT __stdcall put_MinimalSourceHeight (
        /*[in]*/ long _arg1 ) = 0;
      virtual HRESULT __stdcall get_Enabled (
        /*[out,retval]*/ VARIANT_BOOL * value ) = 0;
      virtual HRESULT __stdcall get_SourceLocation (
        /*[out,retval]*/ struct IRectangle * * Location ) = 0;
      virtual HRESULT __stdcall put_SourceLocation (
        /*[in]*/ struct IRectangle * Location ) = 0;
      virtual HRESULT __stdcall get_WindowContainingSource (
        /*[out,retval]*/ long * HWnd ) = 0;
      virtual HRESULT __stdcall put_WindowContainingSource (
        /*[in]*/ long HWnd ) = 0;
      virtual HRESULT __stdcall get_FocusLocation (
        /*[out,retval]*/ struct IRectangle * * Location ) = 0;
      virtual HRESULT __stdcall put_FocusLocation (
        /*[in]*/ struct IRectangle * Location ) = 0;
      virtual HRESULT __stdcall get_DestinationLocation (
        /*[out,retval]*/ struct IRectangle * * Location ) = 0;
      virtual HRESULT __stdcall put_DestinationLocation (
        /*[in]*/ struct IRectangle * Location ) = 0;
      virtual HRESULT __stdcall get_AllowDestinationToOverlapSourceLocation (
        /*[out,retval]*/ VARIANT_BOOL * value ) = 0;
      virtual HRESULT __stdcall put_AllowDestinationToOverlapSourceLocation (
        /*[in]*/ VARIANT_BOOL value ) = 0;
      virtual HRESULT __stdcall get_OnShowRouteMouseToFocus (
        /*[out,retval]*/ VARIANT_BOOL * value ) = 0;
      virtual HRESULT __stdcall put_OnShowRouteMouseToFocus (
        /*[in]*/ VARIANT_BOOL value ) = 0;
      virtual HRESULT __stdcall get_AddPaddingToDestinationLocation (
        /*[out,retval]*/ VARIANT_BOOL * value ) = 0;
      virtual HRESULT __stdcall put_AddPaddingToDestinationLocation (
        /*[in]*/ VARIANT_BOOL value ) = 0;
      virtual HRESULT __stdcall get_UseCaretLocationInsteadOfFocus (
        /*[out,retval]*/ VARIANT_BOOL * value ) = 0;
      virtual HRESULT __stdcall put_UseCaretLocationInsteadOfFocus (
        /*[in]*/ VARIANT_BOOL value ) = 0;
      virtual HRESULT __stdcall get_CurrentScenario (
        /*[out,retval]*/ BSTR * Name ) = 0;
      virtual HRESULT __stdcall RegisterWithUI (
        /*[in]*/ BSTR Name,
        /*[in]*/ BSTR defaultWindowState ) = 0;
      virtual HRESULT __stdcall Show ( ) = 0;
      virtual HRESULT __stdcall UpdateLocations ( ) = 0;
      virtual HRESULT __stdcall Hide ( ) = 0;
};

struct __declspec(uuid("09ef40d5-8ea2-48d7-a760-3317e3cab2dc"))
IMagnification10 : IMagnification9
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_TetheredViewSettings (
        /*[out,retval]*/ struct ITetheredViewSettings * * ppTetheredViewSettings ) = 0;
};

struct __declspec(uuid("9b031763-5952-453e-8688-dca3c5c656b3"))
IZoomText10 : IZoomText9
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Magnification10 (
        /*[out,retval]*/ struct IMagnification10 * * ppObj ) = 0;
};

struct __declspec(uuid("30bb8be8-4275-4042-90da-5f9698744f19"))
ZoomText;
    // interface IZoomText
    // interface IZoomText2
    // interface IZoomText3
    // interface IZoomText4
    // interface IZoomText5
    // interface IZoomText6
    // interface IZoomText7
    // interface IZoomText8
    // interface IZoomText9
    // interface IZoomText10
    // [ default ] interface IZoomText11

struct __declspec(uuid("ff32c95f-83aa-4bbb-bde9-ecd790ef85fb"))
IMagnification11 : IMagnification10
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_PointerEnhancements3 (
        /*[out,retval]*/ struct IPointerEnhancements3 * * ppPointerEnhancements ) = 0;
};

struct __declspec(uuid("d4c0c54a-5414-42e7-b153-62c9b3e7febf"))
IZoomText11 : IZoomText10
{
    //
    // Raw methods provided by interface
    //

      virtual HRESULT __stdcall get_Magnification11 (
        /*[out,retval]*/ struct IMagnification11 * * ppObj ) = 0;
};

//
// Named GUID constants initializations
//

extern "C" const GUID __declspec(selectany) LIBID_AiSquared =
    {0x9fbbc98e,0xae78,0x4a1c,{0xb6,0x35,0x1e,0xca,0x2f,0xbf,0xfb,0x40}};
extern "C" const GUID __declspec(selectany) IID_IZTCommand =
    {0xcc675e9b,0xd54b,0x4752,{0xae,0xbe,0x20,0xf1,0xb6,0x49,0x62,0x01}};
extern "C" const GUID __declspec(selectany) IID_IAhoiManager =
    {0xccb88338,0x5d06,0x4d72,{0x8e,0x08,0x52,0x6e,0xab,0xed,0x44,0x58}};
extern "C" const GUID __declspec(selectany) IID_IAhoiManager2 =
    {0xba722d2b,0x4323,0x495d,{0x84,0xff,0x39,0xd6,0x94,0xd1,0x70,0xbb}};
extern "C" const GUID __declspec(selectany) IID_IEventDefinition =
    {0x83012579,0xfec8,0x4b8a,{0xa6,0xb6,0x9e,0x91,0x44,0xa7,0xe4,0x7f}};
extern "C" const GUID __declspec(selectany) IID_IEventManager =
    {0x5d2381cf,0x0b7d,0x4554,{0xb3,0xa6,0xe6,0x7f,0x6e,0x98,0xdf,0xb3}};
extern "C" const GUID __declspec(selectany) IID_IEventManager2 =
    {0xe0140240,0xfba2,0x4e2b,{0xa4,0xed,0xe7,0xad,0x17,0x6e,0x7b,0xc6}};
extern "C" const GUID __declspec(selectany) IID_IHotkeys =
    {0xf8d5580b,0xbb40,0x4fbc,{0xa8,0x8d,0xd4,0xee,0x78,0x2b,0xee,0x0e}};
extern "C" const GUID __declspec(selectany) IID_IHotkeys2 =
    {0x8e5f9c98,0x48c4,0x4322,{0xab,0x3f,0xd0,0x88,0x79,0xd9,0x15,0x55}};
extern "C" const GUID __declspec(selectany) IID_IKeyboard =
    {0x04972fbc,0x5254,0x11dc,{0x83,0x14,0x08,0x00,0x20,0x0c,0x9a,0x66}};
extern "C" const GUID __declspec(selectany) IID_ICaretEnhancements =
    {0xd0433f69,0x0d8c,0x4775,{0x83,0xf9,0x1f,0x04,0xf9,0x7c,0x3a,0x72}};
extern "C" const GUID __declspec(selectany) IID_IRectangle =
    {0x22ab4f67,0x91c3,0x4dd9,{0x9b,0xc0,0x5b,0xd1,0xd5,0xab,0x9b,0x90}};
extern "C" const GUID __declspec(selectany) IID_ICaretEnhancements2 =
    {0x92efd367,0x80cc,0x4ddc,{0xa8,0x41,0xea,0x00,0x0c,0x53,0x1d,0x39}};
extern "C" const GUID __declspec(selectany) IID_ICaretEnhancements3 =
    {0xbb0a2d5b,0x960f,0x4c98,{0xbe,0xed,0x44,0x54,0xb7,0x3a,0x36,0xf1}};
extern "C" const GUID __declspec(selectany) IID_ICaretEnhancements4 =
    {0xa05e200e,0x7e70,0x4c7e,{0x99,0xac,0x79,0x5b,0xba,0x60,0x88,0x09}};
extern "C" const GUID __declspec(selectany) IID_IColorEnhancements =
    {0x0370fad7,0x0e6b,0x46f1,{0xa0,0x08,0xc6,0xd6,0x89,0x49,0x3f,0xce}};
extern "C" const GUID __declspec(selectany) IID_IColorEnhancements2 =
    {0x9453cdaf,0x1e08,0x4861,{0xa5,0xab,0x59,0x9d,0xd5,0xe7,0xfd,0x09}};
extern "C" const GUID __declspec(selectany) IID_IDualMonitor =
    {0x71c6bc10,0xca7b,0x4812,{0x8b,0x1f,0xb6,0x4c,0xb7,0xa5,0x09,0xe7}};
extern "C" const GUID __declspec(selectany) IID_IFocusEnhancements =
    {0x2e51ed2f,0x589a,0x4c74,{0xb9,0x55,0x27,0x3f,0xf8,0xa0,0x41,0x77}};
extern "C" const GUID __declspec(selectany) IID_IFocusEnhancements2 =
    {0x58041971,0x3a0b,0x4821,{0xa4,0x36,0x6b,0x94,0x71,0xfd,0xfd,0xc4}};
extern "C" const GUID __declspec(selectany) IID_IFocusEnhancements3 =
    {0x9859118a,0x4c6f,0x41e8,{0xa2,0x8d,0xa6,0xe6,0xc4,0x48,0x09,0x33}};
extern "C" const GUID __declspec(selectany) IID_IFocusEnhancements4 =
    {0xd90db93e,0xeef3,0x461b,{0x9c,0xd6,0x19,0x9b,0xb2,0x52,0xef,0x3b}};
extern "C" const GUID __declspec(selectany) IID_IFontEnhancements =
    {0x0ee21611,0xd296,0x4c6d,{0x8d,0x28,0x87,0xd7,0xbf,0xc6,0x26,0xfa}};
extern "C" const GUID __declspec(selectany) IID_IPower =
    {0xffba1585,0x96aa,0x4be7,{0xbf,0x8e,0x79,0x96,0xbe,0x40,0x56,0x83}};
extern "C" const GUID __declspec(selectany) IID_IZoomWindow =
    {0xb9966bd6,0x5a59,0x4a20,{0xb4,0xd5,0xc9,0x7e,0x70,0x80,0x75,0x27}};
extern "C" const GUID __declspec(selectany) IID_IPointerEnhancements =
    {0x41c19ac7,0x4d28,0x4d3b,{0xa1,0x7f,0x70,0x4d,0x0f,0x1b,0x38,0x72}};
extern "C" const GUID __declspec(selectany) IID_IPointerEnhancements2 =
    {0xdf2b31ee,0xa0a2,0x4f5d,{0x8f,0x29,0x96,0x9b,0x91,0xba,0xf2,0x48}};
extern "C" const GUID __declspec(selectany) IID_IPointerEnhancements3 =
    {0x4dad7131,0xee64,0x4c3d,{0x82,0xa6,0xdb,0x37,0x63,0xfb,0xb6,0x0f}};
extern "C" const GUID __declspec(selectany) IID_ITracking =
    {0x9a59b310,0x74f6,0x4d43,{0xb0,0xab,0x1f,0x44,0xda,0x82,0x68,0xe0}};
extern "C" const GUID __declspec(selectany) IID_ITracking2 =
    {0x0e890643,0x4d5b,0x4e20,{0x8a,0x72,0x80,0xc8,0xad,0x25,0x11,0xf9}};
extern "C" const GUID __declspec(selectany) IID_IViewLocator =
    {0x91b8c0cd,0x93cf,0x46f3,{0xab,0xba,0x04,0xc6,0x1a,0x13,0xba,0x0c}};
extern "C" const GUID __declspec(selectany) IID_IMagnification =
    {0x33fbe571,0xa41d,0x49cf,{0x84,0xc7,0x5e,0x22,0x07,0xe3,0x7e,0x98}};
extern "C" const GUID __declspec(selectany) IID_IScreenHighlight =
    {0x1a1f44c1,0x83b2,0x4d12,{0xb6,0xfe,0x62,0x97,0x51,0xc1,0x34,0xec}};
extern "C" const GUID __declspec(selectany) IID_IScreenHighlight2 =
    {0xeb53ca25,0x96d6,0x4978,{0xbc,0x65,0x4c,0x3b,0x21,0x18,0xce,0xe5}};
extern "C" const GUID __declspec(selectany) IID_IMagnification2 =
    {0xb8ee8cbb,0x6357,0x44ef,{0xa0,0x24,0x0b,0x75,0x6d,0x0d,0x77,0x30}};
extern "C" const GUID __declspec(selectany) IID_ICCTV =
    {0x050e0e11,0x3d0a,0x4f6e,{0xa6,0x34,0xc2,0x27,0x0e,0x30,0xdc,0x1b}};
extern "C" const GUID __declspec(selectany) IID_IMagnification3 =
    {0x7fecb1f1,0xc6d4,0x4f80,{0x87,0xb4,0x06,0xdc,0xaa,0xbe,0xbf,0x57}};
extern "C" const GUID __declspec(selectany) IID_IPoint =
    {0xe9bed2bf,0x8834,0x49f9,{0xad,0x4c,0x12,0xc3,0xcf,0x73,0x73,0xad}};
extern "C" const GUID __declspec(selectany) IID_IMouse =
    {0x4c2662b3,0x4cf7,0x4b05,{0xb0,0xb0,0x53,0xae,0x74,0xee,0x8d,0x5d}};
extern "C" const GUID __declspec(selectany) IID_IAppReader =
    {0xc4c5a470,0x4f53,0x4bbf,{0xa5,0x34,0xba,0x88,0xe9,0xfb,0xbe,0x5f}};
extern "C" const GUID __declspec(selectany) IID_IMouseEcho =
    {0x1203b332,0x4ef0,0x41fd,{0xbc,0x24,0x76,0x35,0x03,0xb8,0xdc,0x90}};
extern "C" const GUID __declspec(selectany) IID_IMouseEcho2 =
    {0x0472df6c,0x835a,0x4180,{0xa3,0x5a,0xa5,0x60,0x8f,0xa2,0xfc,0xe8}};
extern "C" const GUID __declspec(selectany) IID_IReadingZoneObject =
    {0xcb508dd4,0x5076,0x4b3c,{0xb7,0x92,0x62,0x9d,0x6c,0x37,0xaf,0x41}};
extern "C" const GUID __declspec(selectany) IID_IReadingZones =
    {0xa0a71491,0x2b73,0x43f3,{0x9e,0x6b,0x5a,0x9f,0xdd,0xdd,0xc3,0xd1}};
extern "C" const GUID __declspec(selectany) IID_ITypingEcho =
    {0x865c25b5,0x9a75,0x4e41,{0xb1,0x82,0xdc,0xa1,0x76,0x82,0x55,0xe3}};
extern "C" const GUID __declspec(selectany) IID_IVerbosity =
    {0x7f5432aa,0x9729,0x4fd3,{0xa7,0x83,0x2c,0x02,0xfa,0xbe,0x5b,0x86}};
extern "C" const GUID __declspec(selectany) IID_IReader =
    {0xcde9e8a8,0x03a7,0x4413,{0x86,0xa3,0xac,0xa3,0x0f,0x30,0x5a,0xc1}};
extern "C" const GUID __declspec(selectany) IID_IProgramEcho =
    {0xbfff5140,0xba03,0x40b0,{0x81,0x31,0xec,0x64,0x67,0x3b,0xc7,0x35}};
extern "C" const GUID __declspec(selectany) IID_IReader2 =
    {0x5f41aadc,0x84dc,0x445d,{0xbb,0x22,0x0f,0xde,0x09,0xb9,0x5e,0x91}};
extern "C" const GUID __declspec(selectany) IID_IDocReader =
    {0x8423fbeb,0xfeaf,0x4248,{0x96,0x38,0x15,0x6a,0x75,0x43,0xea,0x91}};
extern "C" const GUID __declspec(selectany) IID_IRecorder =
    {0x2aeb500e,0x85ad,0x4808,{0x83,0x6b,0x2f,0x15,0x12,0x69,0x79,0x66}};
extern "C" const GUID __declspec(selectany) IID_IReader3 =
    {0x129e7a0e,0x9e23,0x469d,{0xa2,0xca,0xde,0x3b,0xae,0xca,0xf4,0x5d}};
extern "C" const GUID __declspec(selectany) IID_IReader4 =
    {0x0c32cc2f,0x22f4,0x4980,{0xa4,0xd8,0x6c,0xda,0x1f,0x1b,0x4d,0x8d}};
extern "C" const GUID __declspec(selectany) IID_IScriptInformation =
    {0xfa636707,0xc09a,0x4fd9,{0x8a,0x1b,0x83,0x8a,0x5a,0x50,0x5a,0x4c}};
extern "C" const GUID __declspec(selectany) IID_IScriptConfiguration =
    {0xff065601,0xdc5c,0x49ad,{0xab,0x8d,0x58,0x32,0x58,0x85,0xbe,0x0b}};
extern "C" const GUID __declspec(selectany) IID_IScriptConfiguration2 =
    {0x627f824e,0xcf7c,0x43d9,{0xa4,0xcf,0x1c,0x13,0x9a,0x93,0x4a,0x2e}};
extern "C" const GUID __declspec(selectany) IID_IZoomTextSettings =
    {0xee7b5cc9,0xbf3e,0x493d,{0xae,0xd4,0xa0,0xa0,0xa1,0x0a,0x9a,0x8c}};
extern "C" const GUID __declspec(selectany) IID_IZoomTextSettings2 =
    {0xe874a180,0xd7c9,0x4b21,{0xa6,0x38,0x98,0x2d,0x36,0xf5,0xea,0x7e}};
extern "C" const GUID __declspec(selectany) IID_IZoomTextSettings3 =
    {0x51b35190,0x807c,0x4ac8,{0xb7,0x4f,0x3a,0x3f,0xd8,0x3e,0x6f,0x86}};
extern "C" const GUID __declspec(selectany) IID_IZoomTextSettings4 =
    {0x84c39c47,0x0cfb,0x43a8,{0xb8,0x8e,0x0c,0x66,0x62,0x00,0x08,0x77}};
extern "C" const GUID __declspec(selectany) IID_IZoomTextSettings5 =
    {0xc8050fe3,0x1249,0x4b16,{0xa8,0xc9,0x81,0xdd,0x21,0xb1,0x0a,0xd5}};
extern "C" const GUID __declspec(selectany) IID_IZoomTextSettings6 =
    {0xe73eaf69,0x0892,0x48f5,{0xa0,0x78,0x53,0xd3,0x7a,0x3b,0x65,0x55}};
extern "C" const GUID __declspec(selectany) IID_IVoice =
    {0xa2fbf963,0x0748,0x4266,{0xa0,0x4b,0x8c,0x54,0x46,0x61,0x26,0xd5}};
extern "C" const GUID __declspec(selectany) IID_IObjectCollection =
    {0xe9ef732f,0x25ef,0x4d19,{0xa0,0xd2,0xfe,0x8f,0x6d,0x3a,0x1b,0xbb}};
extern "C" const GUID __declspec(selectany) IID_ISpeech =
    {0xb7271c8c,0x3a94,0x4831,{0x88,0x3b,0x81,0xba,0x18,0xb8,0x76,0x64}};
extern "C" const GUID __declspec(selectany) IID_ISpeaker =
    {0xc7149863,0x61d3,0x422f,{0xaa,0x2c,0x0d,0xca,0x65,0x49,0x14,0xd5}};
extern "C" const GUID __declspec(selectany) IID_ISpeech2 =
    {0xcd16491d,0x29de,0x4cb2,{0xa4,0xd9,0x2a,0xd4,0x23,0xfe,0x3c,0x6e}};
extern "C" const GUID __declspec(selectany) IID_IScriptManager =
    {0x729772a3,0x83e7,0x4d86,{0xa3,0x0c,0x78,0x0c,0x24,0xd0,0xbb,0x6c}};
extern "C" const GUID __declspec(selectany) IID_IZoomText =
    {0xde188a1c,0x7426,0x46f4,{0x95,0xe2,0x40,0x04,0xa5,0xf6,0x64,0xd9}};
extern "C" const GUID __declspec(selectany) IID_ITextSearchOption =
    {0x6820972a,0x1abd,0x4bcf,{0x92,0x4a,0x60,0x05,0x3f,0xac,0x4a,0x8d}};
extern "C" const GUID __declspec(selectany) IID_IApplicationObject =
    {0x30ef42de,0x166e,0x4bd4,{0xb8,0x64,0x0b,0xec,0x8d,0xc1,0x43,0xf3}};
extern "C" const GUID __declspec(selectany) IID_IFontObject =
    {0xa3b6c1b2,0x5b5a,0x48d3,{0x88,0x9b,0xf7,0x7b,0x40,0x87,0xe8,0x60}};
extern "C" const GUID __declspec(selectany) IID_ITextObject =
    {0x7dc44c70,0xd1e4,0x4477,{0x9e,0x4a,0xcc,0xdb,0x38,0xc8,0x62,0xf7}};
extern "C" const GUID __declspec(selectany) IID_ITextCursor =
    {0xa04731f3,0x3f79,0x4afd,{0x86,0x58,0x16,0x73,0xd5,0xe5,0x6e,0xce}};
extern "C" const GUID __declspec(selectany) IID_ITextSearch =
    {0x0d7614b7,0xc695,0x4527,{0x9b,0x99,0xac,0xa8,0x04,0xaa,0xcb,0x5e}};
extern "C" const GUID __declspec(selectany) IID_IApplicationSearch =
    {0xa4e4b0f5,0x5321,0x4e2c,{0x95,0x26,0xa5,0xb3,0x3e,0x89,0x0d,0x17}};
extern "C" const GUID __declspec(selectany) IID_IWindowSearch =
    {0x67c6cf6a,0xafda,0x44be,{0xbc,0xf9,0xc7,0x0e,0x28,0xc9,0xee,0x91}};
extern "C" const GUID __declspec(selectany) IID_IWindowObject =
    {0x5a1f732f,0x6c70,0x4b4e,{0xbd,0xf8,0xb0,0xec,0xf9,0x50,0x01,0x34}};
extern "C" const GUID __declspec(selectany) IID_ICheckBox =
    {0x477f6a4d,0xad3d,0x49be,{0xa9,0x90,0xc5,0x6d,0xd5,0x26,0x14,0xfb}};
extern "C" const GUID __declspec(selectany) IID_IItemObject =
    {0xae0e849f,0xed2b,0x494d,{0x9a,0x02,0x9d,0xb2,0xf0,0x21,0xdd,0xa5}};
extern "C" const GUID __declspec(selectany) IID_IComboBox =
    {0xc644815f,0x2157,0x4854,{0x86,0x1d,0xe4,0x33,0xda,0x8d,0xa5,0xb0}};
extern "C" const GUID __declspec(selectany) IID_IEditBox =
    {0x37e5004f,0x2bbd,0x4800,{0xbd,0x87,0xb8,0x88,0x3b,0x6a,0x2a,0x83}};
extern "C" const GUID __declspec(selectany) IID_ILink =
    {0xfb9e3e9b,0x374d,0x4e3f,{0x92,0x03,0x7c,0x3d,0x8f,0x84,0x8f,0x41}};
extern "C" const GUID __declspec(selectany) IID_IListView =
    {0x32a532d8,0x5f54,0x4e5a,{0x87,0x6a,0x73,0x7a,0x87,0xc8,0xce,0xe1}};
extern "C" const GUID __declspec(selectany) IID_IMenuItem =
    {0x836a99ad,0xbcbe,0x4534,{0xa8,0xa2,0x73,0xad,0xdf,0xcc,0x75,0x71}};
extern "C" const GUID __declspec(selectany) IID_IRadioButton =
    {0x0680f1b0,0x823e,0x4953,{0xa9,0xff,0xf5,0x2c,0x40,0x7a,0x59,0xfd}};
extern "C" const GUID __declspec(selectany) IID_IScrollBar =
    {0x3656a1fc,0xdfea,0x4acf,{0x9c,0x78,0x67,0x5b,0xe5,0xea,0x27,0x2d}};
extern "C" const GUID __declspec(selectany) IID_ITrackBar =
    {0x68dd54e0,0x183d,0x41ae,{0xbf,0x86,0x4d,0xa4,0x34,0x81,0x43,0x02}};
extern "C" const GUID __declspec(selectany) IID_ITreeView =
    {0x4f521c31,0xee39,0x4cf7,{0xa2,0x00,0xe9,0x85,0x0a,0x9c,0x07,0x0c}};
extern "C" const GUID __declspec(selectany) IID_ISpeechEventObject =
    {0x8511473e,0x8fde,0x4327,{0xbf,0xad,0xec,0x59,0xf7,0x7f,0xcb,0x3f}};
extern "C" const GUID __declspec(selectany) IID_IEnvironment =
    {0xc27bb1e7,0x6142,0x4a9d,{0x8d,0xb1,0x85,0x71,0xb0,0x9e,0x43,0x63}};
extern "C" const GUID __declspec(selectany) IID_IWindowObjectOption =
    {0xd226d606,0xa89c,0x4277,{0xa3,0x96,0xab,0x57,0xf9,0xd2,0xc1,0xbd}};
extern "C" const GUID __declspec(selectany) IID_IWindowObject2 =
    {0xf71a5b7c,0xbb03,0x45ac,{0x97,0x03,0xdd,0xff,0xf9,0xa9,0x48,0x07}};
extern "C" const GUID __declspec(selectany) IID_IHeaderControl =
    {0x19e19ae5,0xd44b,0x4c67,{0xba,0x8e,0x37,0xbd,0xf9,0x71,0xbf,0x90}};
extern "C" const GUID __declspec(selectany) IID_ICheckBox2 =
    {0x4a9140b5,0x7c86,0x4a9c,{0x8e,0xa9,0x5c,0x84,0x75,0x58,0x41,0xe1}};
extern "C" const GUID __declspec(selectany) IID_IItemObject2 =
    {0x97787e6b,0xa70d,0x4a65,{0xa7,0x4a,0x10,0xa3,0x3c,0x03,0x1b,0x61}};
extern "C" const GUID __declspec(selectany) IID_IComboBox2 =
    {0xa1ca3f99,0x86f1,0x4b78,{0x92,0x67,0x04,0x6a,0xd3,0x27,0x82,0xc7}};
extern "C" const GUID __declspec(selectany) IID_IEditBox2 =
    {0xef4fe0d9,0x8e73,0x4e99,{0x9d,0x98,0x44,0x38,0xa4,0xc0,0x23,0xb1}};
extern "C" const GUID __declspec(selectany) IID_ILink2 =
    {0xf2a6d33c,0xf60b,0x4e89,{0x98,0xf2,0xc0,0x0b,0x44,0x13,0xbe,0xfe}};
extern "C" const GUID __declspec(selectany) IID_IListView2 =
    {0xba4119f3,0x7735,0x4c7f,{0x98,0x0d,0xf9,0x2f,0x20,0xb1,0x03,0xd3}};
extern "C" const GUID __declspec(selectany) IID_IMenuItem2 =
    {0xe11c2304,0xa3b0,0x4f17,{0x8c,0x36,0x19,0x70,0xd7,0x09,0x15,0x6a}};
extern "C" const GUID __declspec(selectany) IID_IObjectStore =
    {0xe81982ec,0x7a3a,0x4d15,{0xb1,0x26,0x75,0xcc,0xc5,0x20,0xbd,0x81}};
extern "C" const GUID __declspec(selectany) IID_IRadioButton2 =
    {0x93cefb5d,0xe673,0x434a,{0xaf,0x70,0x93,0xd4,0xa6,0xfe,0xe9,0xd8}};
extern "C" const GUID __declspec(selectany) IID_IScrollBar2 =
    {0x179608af,0x19d4,0x4d94,{0x83,0xfc,0x31,0x58,0x14,0xb0,0xc0,0xa9}};
extern "C" const GUID __declspec(selectany) IID_ITrackBar2 =
    {0x2f6b91fe,0x8dad,0x40c6,{0x81,0x51,0xd3,0x53,0x35,0x85,0xba,0xdd}};
extern "C" const GUID __declspec(selectany) IID_ITreeView2 =
    {0xc8d6adcf,0xe992,0x45ef,{0xbb,0x3f,0xa9,0x57,0x2d,0xc8,0x57,0x52}};
extern "C" const GUID __declspec(selectany) IID_IWindowSearchOption =
    {0x6f4c7c49,0x96a6,0x4c87,{0x92,0x6a,0x79,0x08,0x3a,0x19,0xd5,0x34}};
extern "C" const GUID __declspec(selectany) IID_IWindowSearch2 =
    {0xffc01288,0xcb56,0x4c56,{0xb0,0x82,0xee,0xdd,0xd8,0xc0,0xe1,0x44}};
extern "C" const GUID __declspec(selectany) IID_IWebPage =
    {0x87908e23,0xdcfb,0x4a32,{0x82,0xc6,0x5e,0x54,0xc4,0x87,0x0d,0x4d}};
extern "C" const GUID __declspec(selectany) IID_IZoomText2 =
    {0xc954470b,0x98e8,0x4214,{0xa0,0x11,0xb5,0x56,0xdb,0xdf,0x26,0xa6}};
extern "C" const GUID __declspec(selectany) IID_ICCTV2 =
    {0x22e2cc6c,0xe8e3,0x4209,{0xbb,0xfd,0xd4,0xcc,0x65,0xfa,0x61,0x3a}};
extern "C" const GUID __declspec(selectany) IID_ICCTV3 =
    {0x4461cd62,0x37bc,0x409e,{0x96,0xcd,0x7f,0x66,0xea,0xb8,0x6c,0xfc}};
extern "C" const GUID __declspec(selectany) IID_IMagnification4 =
    {0xac9927f4,0xc123,0x4730,{0xb9,0x1c,0x26,0x6a,0xaa,0x93,0xd2,0x2a}};
extern "C" const GUID __declspec(selectany) IID_IZoomText3 =
    {0xab6dcbfd,0x6aa8,0x4f70,{0xb3,0xa6,0x19,0xe9,0x77,0x00,0x19,0xb9}};
extern "C" const GUID __declspec(selectany) IID_ICCTV4 =
    {0x46b53ce7,0x45b6,0x4ef9,{0x98,0xfd,0x58,0xde,0x15,0xbd,0x2b,0x33}};
extern "C" const GUID __declspec(selectany) IID_IMagnification5 =
    {0x1cfc89ff,0x5c33,0x4db7,{0xaa,0xaf,0x4b,0x4b,0xf7,0x66,0x5d,0x2a}};
extern "C" const GUID __declspec(selectany) IID_IZoomText4 =
    {0xc65cd7e2,0x45a5,0x46f4,{0x91,0x65,0x80,0xc9,0x0b,0xdd,0x9e,0x0b}};
extern "C" const GUID __declspec(selectany) IID_IMagnification6 =
    {0x79acb813,0xa53b,0x4c99,{0xa5,0x7f,0x12,0x9b,0x54,0x6e,0xb2,0xc3}};
extern "C" const GUID __declspec(selectany) IID_IZoomText5 =
    {0xe2edafe4,0x9f12,0x4902,{0x90,0x86,0x5f,0x60,0x05,0x16,0xc5,0xda}};
extern "C" const GUID __declspec(selectany) IID_ICCTV5 =
    {0xa595d144,0xd88d,0x4724,{0x8a,0x3a,0x5c,0x93,0x7f,0x9f,0x4f,0x29}};
extern "C" const GUID __declspec(selectany) IID_IMagnification7 =
    {0x69c6dc1f,0xd8a0,0x434d,{0x82,0xea,0xf8,0xe4,0x8a,0x6d,0xa8,0x17}};
extern "C" const GUID __declspec(selectany) IID_IZoomText6 =
    {0x4d2bc8ae,0xfe6d,0x41c5,{0x80,0xa1,0x92,0x2f,0x5e,0xb4,0x4f,0x59}};
extern "C" const GUID __declspec(selectany) IID_IControl =
    {0x2802ebf9,0x069f,0x4245,{0x8e,0x35,0x77,0xba,0x2c,0x58,0xf4,0x62}};
extern "C" const GUID __declspec(selectany) IID_IControlAppProperties =
    {0xa9224504,0x4499,0x45ff,{0xa8,0xc9,0xa3,0x27,0xb3,0x28,0xfd,0xd5}};
extern "C" const GUID __declspec(selectany) IID_IControlApp =
    {0x93eb8471,0x756d,0x46fc,{0x98,0x91,0xba,0x8d,0x89,0x3a,0x1c,0x0d}};
extern "C" const GUID __declspec(selectany) IID_IMagnification8 =
    {0x3e3aee84,0x0ed6,0x44a9,{0xa4,0x81,0xfc,0x77,0x70,0x02,0x6f,0x02}};
extern "C" const GUID __declspec(selectany) IID_IZoomText7 =
    {0x1cd1670d,0xbdd5,0x4c8f,{0xa9,0x18,0x00,0xe3,0xd5,0x40,0xe1,0xbd}};
extern "C" const GUID __declspec(selectany) IID_ISpeaker2 =
    {0x92231697,0x6ead,0x408d,{0x93,0x95,0x6a,0x68,0x8b,0x88,0x55,0x86}};
extern "C" const GUID __declspec(selectany) IID_IVoice2 =
    {0xd38f0d27,0xfc81,0x4836,{0x88,0x86,0x0e,0xc9,0xbd,0xb4,0x17,0xd3}};
extern "C" const GUID __declspec(selectany) IID_ISpeech3 =
    {0xb0b9cb1d,0x3369,0x482d,{0x8c,0x2e,0x3c,0xb2,0x54,0xdb,0xff,0x0c}};
extern "C" const GUID __declspec(selectany) IID_IZoomText8 =
    {0x796718e4,0xf2b9,0x4d7d,{0x89,0x70,0xac,0x1a,0x26,0xd8,0x16,0xf7}};
extern "C" const GUID __declspec(selectany) IID_IFontEnhancements2 =
    {0x97ea7ed1,0x3acc,0x4cba,{0x8d,0xf9,0x4e,0xcb,0xe9,0x55,0x82,0x71}};
extern "C" const GUID __declspec(selectany) IID_IMagnification9 =
    {0xd1d89c6e,0x4cdb,0x4b66,{0xaf,0x63,0x57,0xca,0x40,0x55,0x54,0x07}};
extern "C" const GUID __declspec(selectany) IID_IZoomText9 =
    {0xd629bc1e,0x21e2,0x4509,{0x93,0x47,0xe7,0xd3,0xfa,0xdf,0x84,0x70}};
extern "C" const GUID __declspec(selectany) IID_ITetheredViewSettings =
    {0x9a67b4ec,0x2046,0x4227,{0x80,0xca,0x44,0x73,0x9b,0x3b,0x52,0x56}};
extern "C" const GUID __declspec(selectany) IID_ITetheredViewScenario =
    {0x915c2a11,0x8a83,0x4608,{0x9a,0xef,0xaa,0x9a,0xfb,0x47,0xb8,0xe0}};
extern "C" const GUID __declspec(selectany) IID_IMagnification10 =
    {0x09ef40d5,0x8ea2,0x48d7,{0xa7,0x60,0x33,0x17,0xe3,0xca,0xb2,0xdc}};
extern "C" const GUID __declspec(selectany) IID_IZoomText10 =
    {0x9b031763,0x5952,0x453e,{0x86,0x88,0xdc,0xa3,0xc5,0xc6,0x56,0xb3}};
extern "C" const GUID __declspec(selectany) CLSID_ZoomText =
    {0x30bb8be8,0x4275,0x4042,{0x90,0xda,0x5f,0x96,0x98,0x74,0x4f,0x19}};
extern "C" const GUID __declspec(selectany) IID_IMagnification11 =
    {0xff32c95f,0x83aa,0x4bbb,{0xbd,0xe9,0xec,0xd7,0x90,0xef,0x85,0xfb}};
extern "C" const GUID __declspec(selectany) IID_IZoomText11 =
    {0xd4c0c54a,0x5414,0x42e7,{0xb1,0x53,0x62,0xc9,0xb3,0xe7,0xfe,0xbf}};

#pragma pack(pop)
